@@ -61,7 +61,18 @@
 // Singleton application instance stuff (Qt/X11 only atm.)
 //
 
+#if QT_VERSION < 0x050000
 #if defined(Q_WS_X11)
+#define CONFIG_X11
+#endif
+#else
+#if defined(QT_X11EXTRAS_LIB)
+#define CONFIG_X11
+#endif
+#endif
+
+
+#ifdef CONFIG_X11
 
 #ifdef CONFIG_VST
 #include "qtractorVstPlugin.h"
@@ -76,8 +87,36 @@
 
 #define QTRACTOR_XUNIQUE "qtractorApplication"
 
+#if QT_VERSION >= 0x050100
+
+#include <xcb/xcb.h>
+#include <xcb/xproto.h>
+
+#include <QAbstractNativeEventFilter>
+
+class qtractorApplication;
+
+class qtractorXcbEventFilter : public QAbstractNativeEventFilter
+{
+public:
+
+	// Constructor.
+	qtractorXcbEventFilter(qtractorApplication *pApp)
+		: QAbstractNativeEventFilter(), m_pApp(pApp) {}
+
+	// XCB event filter (virtual processor).
+	bool nativeEventFilter(const QByteArray& eventType, void *message, long *);
+
+private:
+
+	// Instance variable.
+	qtractorApplication *m_pApp;
+};
+
+#endif
+
 #endif	// CONFIG_XUNIQUE
-#endif	// Q_WS_X11
+#endif	// CONFIG_X11
 
 class qtractorApplication : public QApplication
 {
@@ -127,20 +166,32 @@ public:
 				}
 			}
 		}
-	#if defined(Q_WS_X11)
+	#ifdef CONFIG_X11
 	#ifdef CONFIG_XUNIQUE
 		m_pDisplay = QX11Info::display();
 		m_aUnique  = XInternAtom(m_pDisplay, QTRACTOR_XUNIQUE, false);
 		XGrabServer(m_pDisplay);
 		m_wOwner = XGetSelectionOwner(m_pDisplay, m_aUnique);
 		XUngrabServer(m_pDisplay);
+	#if QT_VERSION >= 0x050100
+		m_pXcbEventFilter = new qtractorXcbEventFilter(this);
+		installNativeEventFilter(m_pXcbEventFilter);
 	#endif
-	#endif
+	#endif	// CONFIG_XUNIQUE
+	#endif	// CONFIG_X11
 	}
 
 	// Destructor.
 	~qtractorApplication()
 	{
+	#ifdef CONFIG_X11
+	#ifdef CONFIG_XUNIQUE
+	#if QT_VERSION >= 0x050100
+		removeNativeEventFilter(m_pXcbEventFilter);
+		delete m_pXcbEventFilter;
+	#endif
+	#endif	// CONFIG_XUNIQUE
+	#endif	// CONFIG_X11
 		if (m_pMyTranslator) delete m_pMyTranslator;
 		if (m_pQtTranslator) delete m_pQtTranslator;
 	}
@@ -149,14 +200,14 @@ public:
 	void setMainWidget(QWidget *pWidget)
 	{
 		m_pWidget = pWidget;
-	#if defined(Q_WS_X11)
+	#ifdef CONFIG_X11
 	#ifdef CONFIG_XUNIQUE
 		XGrabServer(m_pDisplay);
 		m_wOwner = m_pWidget->winId();
 		XSetSelectionOwner(m_pDisplay, m_aUnique, m_wOwner, CurrentTime);
 		XUngrabServer(m_pDisplay);
-	#endif
-	#endif
+	#endif	// CONFIG_XUNIQUE
+	#endif	// CONFIG_X11
 	}
 
 	QWidget *mainWidget() const { return m_pWidget; }
@@ -165,7 +216,7 @@ public:
     // and raise its proper main widget...
 	bool setup()
 	{
-	#if defined(Q_WS_X11)
+	#ifdef CONFIG_X11
 	#ifdef CONFIG_XUNIQUE
 		if (m_wOwner != None) {
 			// First, notify any freedesktop.org WM
@@ -191,7 +242,7 @@ public:
 			XRaiseWindow(m_pDisplay, m_wOwner);
 			// And then, let it get caught on destination
 			// by QApplication::x11EventFilter...
-			QByteArray value = QTRACTOR_XUNIQUE;
+			const QByteArray value = QTRACTOR_XUNIQUE;
 			XChangeProperty(
 				m_pDisplay,
 				m_wOwner,
@@ -203,19 +254,16 @@ public:
 			// Done.
 			return true;
 		}
-	#endif
-	#endif
+	#endif	// CONFIG_XUNIQUE
+	#endif	// CONFIG_X11
 		return false;
 	}
 
-#if defined(Q_WS_X11)
-	bool x11EventFilter(XEvent *pEv)
+#ifdef CONFIG_X11
+#ifdef CONFIG_XUNIQUE
+	void x11PropertyNotify(Window w)
 	{
-	#ifdef CONFIG_XUNIQUE
-		if (m_pWidget && m_wOwner != None
-			&& pEv->type == PropertyNotify
-			&& pEv->xproperty.window == m_wOwner
-			&& pEv->xproperty.state == PropertyNewValue) {
+		if (m_pWidget && m_wOwner == w) {
 			// Always check whether our property-flag is still around...
 			Atom aType;
 			int iFormat = 0;
@@ -246,6 +294,15 @@ public:
 			if (iItems > 0 && pData)
 				XFree(pData);
 		}
+	}
+#endif	// CONFIG_XUNIQUE
+#if QT_VERSION < 0x050000
+	bool x11EventFilter(XEvent *pEv)
+	{
+	#ifdef CONFIG_XUNIQUE
+		if (pEv->type == PropertyNotify
+			&& pEv->xproperty.state == PropertyNewValue)
+			x11PropertyNotify(pEv->xproperty.window);
 	#endif
 	#ifdef CONFIG_VST
 		// Let xevents be processed by VST plugin editors...
@@ -255,6 +312,7 @@ public:
 		return QApplication::x11EventFilter(pEv);
 	}
 #endif
+#endif	// CONFIG_X11
 	
 private:
 
@@ -265,15 +323,38 @@ private:
 	// Instance variables.
 	QWidget *m_pWidget;
 
-#if defined(Q_WS_X11)
+#ifdef CONFIG_X11
 #ifdef CONFIG_XUNIQUE
 	Display *m_pDisplay;
 	Atom     m_aUnique;
 	Window   m_wOwner;
+#if QT_VERSION >= 0x050100
+	qtractorXcbEventFilter *m_pXcbEventFilter;
 #endif
-#endif
+#endif	// CONFIG_XUNIQUE
+#endif	// CONFIG_X11
 };
 
+#ifdef CONFIG_X11
+#ifdef CONFIG_XUNIQUE
+#if QT_VERSION >= 0x050100
+// XCB Event filter (virtual processor).
+bool qtractorXcbEventFilter::nativeEventFilter (
+	const QByteArray& eventType, void *message, long * )
+{
+	if (eventType == "xcb_generic_event_t") {
+		xcb_property_notify_event_t *pEv
+			= static_cast<xcb_property_notify_event_t *> (message);
+		if ((pEv->response_type & ~0x80) == XCB_PROPERTY_NOTIFY
+			&& pEv->state == XCB_PROPERTY_NEW_VALUE)
+			m_pApp->x11PropertyNotify(pEv->window);
+	}
+	return false;
+}
+#endif
+#endif	// CONFIG_XUNIQUE
+#endif	// CONFIG_X11
+
 
 //-------------------------------------------------------------------------
 // stacktrace - Signal crash handler.
@@ -472,6 +553,13 @@ static bool update_palette ( QPalette& pal, const QString& sCustomColorTheme )
 // main - The main program trunk.
 //
 
+#if QT_VERSION >= 0x050100
+#ifdef CONFIG_LV2_UI_GTK2
+#undef signals // Collides with GTK symbology
+#include <gtk/gtk.h>
+#endif	// CONFIG_LV2_UI_GTK2
+#endif
+
 int main ( int argc, char **argv )
 {
 	Q_INIT_RESOURCE(qtractor);
@@ -499,6 +587,13 @@ int main ( int argc, char **argv )
 		return 2;
 	}
 
+#if QT_VERSION >= 0x050100
+#ifdef CONFIG_LV2_UI_GTK2
+	// Initialize GTK+ framework (LV2 plug-in UI GTK2 support)...
+	gtk_init(NULL, NULL);
+#endif	// CONFIG_LV2_UI_GTK2
+#endif
+
 	// Special style paths...
 	if (QDir(CONFIG_PLUGINSDIR).exists())
 		app.addLibraryPath(CONFIG_PLUGINSDIR);
