@@ -1,7 +1,7 @@
 // qtractorAudioFile.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -68,6 +68,9 @@ class qtractorAudioFileFactory
 {
 public:
 
+	// Destructor.
+	~qtractorAudioFileFactory();
+
 	// Supported file types.
 	enum FileType { SndFile, VorbisFile, MadFile };
 
