@@ -25,6 +25,8 @@
 
 #include "qtractorOptions.h"
 
+#include "qtractorMessageList.h"
+
 #include <QHeaderView>
 #include <QFileDialog>
 #include <QUrl>
@@ -185,6 +187,9 @@ qtractorFileListItem *qtractorAudioListView::createFileItem (
 	if (pFile->open(sPath)) {
 		pFileItem = new qtractorAudioFileItem(sPath, pFile);
 		pFile->close();
+	} else {
+		qtractorMessageList::append(
+			tr("%1: Audio file not found.").arg(sPath));
 	}
 
 	delete pFile;
@@ -194,4 +199,3 @@ qtractorFileListItem *qtractorAudioListView::createFileItem (
 
 
 // end of qtractorAudioListView.cpp
-
