@@ -1,7 +1,7 @@
 // qtractorAudioMeter.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -205,18 +205,6 @@ qtractorAudioMeterValue::qtractorAudioMeterValue (
 	pAudioMeter->boxLayout()->addWidget(this);
 }
 
-// Default destructor.
-qtractorAudioMeterValue::~qtractorAudioMeterValue (void)
-{
-}
-
-
-// Reset peak holder.
-void qtractorAudioMeterValue::peakReset (void)
-{
-	m_iPeak = 0;
-}
-
 
 // Value refreshment.
 void qtractorAudioMeterValue::refresh (void)
