@@ -1,7 +1,7 @@
 // qtractorClip.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -539,6 +539,12 @@ void qtractorClip::updateEditor ( bool /*bSelectClear*/ )
 	// Do nothing here.
 }
 
+// Clip editor contents update.
+void qtractorClip::updateEditorContents (void)
+{
+	// Do nothing here.
+}
+
 // Clip query-close method (return true if editing is done).
 bool qtractorClip::queryEditor (void)
 {
@@ -694,7 +700,7 @@ bool qtractorClip::loadElement (
 
 
 bool qtractorClip::saveElement (
-	qtractorDocument *pDocument, QDomElement *pElement ) const
+	qtractorDocument *pDocument, QDomElement *pElement )
 {
 	pElement->setAttribute("name", qtractorClip::clipName());
 
