@@ -1,7 +1,7 @@
 // qtractorClip.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -164,16 +164,22 @@ public:
 	virtual void close() = 0;
 
 	// Clip special process cycle executive.
-	virtual void process(unsigned long iFrameStart, unsigned long iFrameEnd) = 0;
+	virtual void process(
+		unsigned long iFrameStart, unsigned long iFrameEnd) = 0;
+
+	// Clip freewheeling process cycle executive (needed for export).
+	virtual void process_export(
+		unsigned long iFrameStart, unsigned long iFrameEnd) = 0;
 
 	// Clip paint method.
 	virtual void draw(QPainter *pPainter, const QRect& clipRect,
 		unsigned long iClipOffset) = 0;
 
-	// Clip editor method.
+	// Clip editor methods.
 	virtual bool startEditor(QWidget *pParent);
 	virtual void resetEditor(bool bSelectClear);
 	virtual void updateEditor(bool bSelectClear);
+	virtual void updateEditorContents();
 	virtual bool queryEditor();
 
 	// Clip tool-tip.
@@ -190,7 +196,7 @@ public:
 
 	// Document element methods.
 	bool loadElement(qtractorDocument *pDocument, QDomElement *pElement);
-	bool saveElement(qtractorDocument *pDocument, QDomElement *pElement) const;
+	bool saveElement(qtractorDocument *pDocument, QDomElement *pElement);
 
 	// Clip fade type textual helper methods.
 	static FadeType fadeInTypeFromText(const QString& sText);
@@ -343,7 +349,7 @@ protected:
 	virtual bool loadClipElement(
 		qtractorDocument *pDocument, QDomElement *pElement) = 0;
 	virtual bool saveClipElement(
-		qtractorDocument *pDocument, QDomElement *pElement) const = 0;
+		qtractorDocument *pDocument, QDomElement *pElement) = 0;
 
 	// Gain fractionalizer(tm)...
 	struct { int num, den; } m_fractGain;
