@@ -1,7 +1,7 @@
 // qtractorClipCommand.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -276,6 +276,31 @@ private:
 };
 
 
+//----------------------------------------------------------------------
+// class qtractorClipRecordExCommand - declaration.
+//
+
+class qtractorClipRecordExCommand : public qtractorCommand
+{
+public:
+
+	// Constructor.
+	qtractorClipRecordExCommand(qtractorClip *pClipRecordEx, bool bClipRecordEx);
+
+	// Virtual command methods.
+	bool redo();
+	bool undo();
+
+private:
+
+	// Instance variables.
+	qtractorTrack *m_pTrack;
+
+	bool           m_bClipRecordEx;
+	qtractorClip  *m_pClipRecordEx;
+};
+
+
 #endif	// __qtractorClipCommand_h
 
 // end of qtractorClipCommand.h
