@@ -1,7 +1,7 @@
 // qtractorCurveFile.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2011, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,6 +28,8 @@
 
 #include "qtractorMidiControl.h"
 
+#include "qtractorMessageList.h"
+
 #include <QDomDocument>
 #include <QDir>
 
@@ -116,8 +118,7 @@ void qtractorCurveFile::save ( qtractorDocument *pDocument,
 	if (m_pCurveList == NULL)
 		return;
 
-	unsigned short iSeq;
-	unsigned short iSeqs = m_items.count();
+	const unsigned short iSeqs = m_items.count();
 	if (iSeqs < 1)
 		return;
 
@@ -125,9 +126,11 @@ void qtractorCurveFile::save ( qtractorDocument *pDocument,
 	if (!file.open(m_sFilename, qtractorMidiFile::Write))
 		return;
 
-	unsigned short iTicksPerBeat = pTimeScale->ticksPerBeat();
+	const unsigned short iTicksPerBeat = pTimeScale->ticksPerBeat();
+	unsigned short iSeq = 0;
+
 	qtractorMidiSequence **ppSeqs = new qtractorMidiSequence * [iSeqs];
-	for (iSeq = 0; iSeq < iSeqs; ++iSeq)
+	for ( ; iSeq < iSeqs; ++iSeq)
 		ppSeqs[iSeq] = new qtractorMidiSequence(QString(), 0, iTicksPerBeat);
 
 	iSeq = 0;
@@ -171,8 +174,8 @@ void qtractorCurveFile::save ( qtractorDocument *pDocument,
 			if (m_pCurveList->currentCurve() == pCurve)
 				iCurrent = pItem->index;
 			eItems.appendChild(eItem);
+			++iSeq;
 		}
-		++iSeq;
 	}
 
 	pElement->appendChild(eItems);
@@ -205,35 +208,43 @@ void qtractorCurveFile::apply ( qtractorTimeScale *pTimeScale )
 	const QString& sFilename = QDir(m_sBaseDir).absoluteFilePath(m_sFilename);
 
 	qtractorMidiFile file;
-	if (!file.open(sFilename, qtractorMidiFile::Read))
+	if (!file.open(sFilename, qtractorMidiFile::Read)) {
+		const QString& sText
+			= QObject::tr("%1: Automation/curve file not found.")
+				.arg(sFilename);
+		qtractorMessageList::append(sText);
 		return;
+	}
 
+	const unsigned short iTicksPerBeat = pTimeScale->ticksPerBeat();
 	unsigned short iSeq = 0;
-	unsigned short iTicksPerBeat = pTimeScale->ticksPerBeat();
 
 	qtractorCurve *pCurrentCurve = NULL;
 
 	QListIterator<Item *> iter(m_items);
 	while (iter.hasNext()) {
 		Item *pItem = iter.next();
-		qtractorCurve *pCurve = (pItem->subject)->curve();
-		if (pCurve == NULL)
-			pCurve = new qtractorCurve(m_pCurveList, pItem->subject, pItem->mode);
-		if (m_iCurrentCurve == int(pItem->index))
-			pCurrentCurve = pCurve;
-		qtractorMidiSequence seq(QString(), pItem->channel, iTicksPerBeat);
-		if (file.readTrack(&seq, iSeq)) {
-			pCurve->readMidiSequence(&seq,
-				pItem->ctype,
-				pItem->channel,
-				pItem->param,
-				pTimeScale);
+		if (pItem->subject) {
+			qtractorCurve *pCurve = (pItem->subject)->curve();
+			if (pCurve == NULL)
+				pCurve = new qtractorCurve(m_pCurveList,
+					pItem->subject, pItem->mode);
+			if (m_iCurrentCurve == int(pItem->index))
+				pCurrentCurve = pCurve;
+			qtractorMidiSequence seq(QString(), pItem->channel, iTicksPerBeat);
+			if (file.readTrack(&seq, iSeq)) {
+				pCurve->readMidiSequence(&seq,
+					pItem->ctype,
+					pItem->channel,
+					pItem->param,
+					pTimeScale);
+			}
+			pCurve->setProcess(pItem->process);
+			pCurve->setCapture(pItem->capture);
+			pCurve->setLocked(pItem->locked);
+			pCurve->setLogarithmic(pItem->logarithmic);
+			pCurve->setColor(pItem->color);
 		}
-		pCurve->setProcess(pItem->process);
-		pCurve->setCapture(pItem->capture);
-		pCurve->setLocked(pItem->locked);
-		pCurve->setLogarithmic(pItem->logarithmic);
-		pCurve->setColor(pItem->color);
 		++iSeq;
 	}
 
@@ -283,4 +294,3 @@ QString qtractorCurveFile::textFromMode ( qtractorCurve::Mode mode )
 
 
 // end of qtractorCurveFile.cpp
-
