@@ -1,7 +1,7 @@
 // qtractorEngine.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -278,8 +278,9 @@ public:
 
 protected:
 
-	// Bus mode change event.
+	// Bus mode/name change events.
 	virtual void updateBusMode() = 0;
+	virtual void updateBusName();
 
 private:
 
