@@ -1,7 +1,7 @@
 // qtractorInsertPlugin.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
    Copyright (C) 2011, Holger Dehnhardt.
 
    This program is free software; you can redistribute it and/or
@@ -64,6 +64,9 @@ public:
 	// Specific named accessors.
 	unsigned short channels() const
 		{ return index(); }
+
+	// Instance cached-deferred accesors.
+	const QString& aboutText();
 };
 
 
@@ -179,6 +182,9 @@ public:
 	// Specific named accessors.
 	unsigned short channels() const
 		{ return index(); }
+
+	// Instance cached-deferred accesors.
+	const QString& aboutText();
 };
 
 
