@@ -1,7 +1,7 @@
 // qtractorInstrument.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -21,8 +21,8 @@
 
 #include "qtractorInstrument.h"
 
-#include <QFileInfo>
 #include <QFile>
+#include <QFileInfo>
 #include <QTextStream>
 #include <QRegExp>
 #include <QDate>
@@ -406,14 +406,14 @@ bool qtractorInstrumentList::save ( const QString& sFilename ) const
 
     ts << sepl << endl;
 	ts << "; " << QObject::tr("Cakewalk Instrument Definition File") << endl;
-/*
+#if 0
     ts << ";"  << endl;
     ts << "; " << QTRACTOR_TITLE " - " << QObject::tr(QTRACTOR_SUBTITLE) << endl;
     ts << "; " << QObject::tr("Version")
        << ": " QTRACTOR_VERSION << endl;
     ts << "; " << QObject::tr("Build")
        << ": " __DATE__ " " __TIME__ << endl;
-*/
+#endif
     ts << ";"  << endl;
     ts << "; " << QObject::tr("File")
        << ": " << QFileInfo(sFilename).fileName() << endl;
@@ -842,7 +842,7 @@ void qtractorInstrumentList::loadMidiPatchNameList (
 		const QString& sTagName = eItem.tagName();
 		if (sTagName == "Patch") {
 			const QString& sProg = eItem.attribute("Name");
-			int iProg = eItem.attribute("ProgramChange").toInt();
+			const int iProg = eItem.attribute("ProgramChange").toInt();
 			patches[iProg] = sProg;
 			for (QDomNode nSubItem = eItem.firstChild();
 					!nSubItem.isNull();
