@@ -1,7 +1,7 @@
 // qtractorInstrument.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -287,7 +287,7 @@ public:
 
 	void removeFile(const QString& sFilename)
 	{
-		int iFile = m_files.indexOf(sFilename);
+		const int iFile = m_files.indexOf(sFilename);
 		if (iFile >= 0)
 			m_files.removeAt(iFile);
 	}
