@@ -52,7 +52,9 @@ class qtractorLv2Worker;
 
 #ifdef CONFIG_LV2_UI
 // LV2 UI support.
+#ifdef CONFIG_LIBSUIL
 #include <suil/suil.h>
+#endif
 #include "lv2/lv2plug.in/ns/extensions/ui/ui.h"
 // LV2 UI data/instance access support.
 #include "lv2/lv2plug.in/ns/ext/data-access/data-access.h"
@@ -64,10 +66,12 @@ class qtractorLv2Worker;
 // LV2 External UI support.
 #include "lv2_external_ui.h"
 #endif
-#if QT_VERSION < 0x050000
-#undef CONFIG_LV2_UI_SHOW
-#endif
+#if QT_VERSION >= 0x050100
+#ifdef CONFIG_LV2_UI_GTK2
+#include <QWindow>
+#endif	// CONFIG_LV2_UI_GTK2
 #endif
+#endif	// CONFIG_LV2_UI
 
 
 #ifdef CONFIG_LV2_STATE
@@ -220,7 +224,13 @@ public:
 	void setEditorVisible(bool bVisible);
 	bool isEditorVisible() const;
 
+	// GUI editor window title methods.
 	void setEditorTitle(const QString& sTitle);
+	void updateEditorTitleEx();
+
+	// GUI editor window (re)position methods.
+	void saveEditorPos();
+	void loadEditorPos();
 
 	// Parameter update method.
 	void updateParam(qtractorPluginParam *pParam, float fValue, bool bUpdate);
@@ -229,11 +239,14 @@ public:
 	static void idleEditorAll();
 
 	// LV2 UI control change method.
-	void lv2_ui_write(uint32_t port_index,
+	void lv2_ui_port_write(uint32_t port_index,
 		uint32_t buffer_size, uint32_t protocol, const void *buffer);
 
+	// LV2 UI portMap method.
+	uint32_t lv2_ui_port_index(const char *port_symbol);
+
 	// LV2 UI resize control (host->ui).
-	void resizeEditor(const QSize& size) const;
+	void lv2_ui_resize(const QSize& size);
 
 	// GUI editor closed state.
 	void setEditorClosed(bool bClosed)
@@ -302,6 +315,7 @@ public:
 	// Whether given preset is internal/read-only.
 	bool isReadOnlyPreset(const QString& sPreset) const;
 #endif
+
 #ifdef CONFIG_LV2_TIME
 	// Update LV2 Time from JACK transport position.
 	static void updateTime(jack_client_t *pJackClient);
@@ -312,6 +326,23 @@ public:
 #endif
 #endif
 
+#ifdef CONFIG_LV2_UI
+protected:
+
+	// Alternate UI instantiation stuff...
+	bool lv2_ui_instantiate(
+		const char *ui_host_uri, const char *plugin_uri,
+		const char *ui_uri,	const char *ui_type_uri,
+		const char *ui_bundle_path, const char *ui_binary_path);
+
+	void lv2_ui_port_event(
+		uint32_t port_index, uint32_t buffer_size,
+		uint32_t format, const void *buffer);
+
+	const void *lv2_ui_extension_data(const char *uri);
+
+#endif
+
 private:
 
 	// Instance variables.
@@ -366,18 +397,29 @@ private:
 	LilvUIs       *m_lv2_uis;
 	LilvUI        *m_lv2_ui;
 
-	LV2_Extension_Data_Feature m_lv2_data_access;
+	LV2_Extension_Data_Feature m_lv2_ui_data_access;
 
-	LV2_Feature    m_lv2_data_access_feature;
-	LV2_Feature    m_lv2_instance_access_feature;
+	LV2_Feature    m_lv2_ui_data_access_feature;
+	LV2_Feature    m_lv2_ui_instance_access_feature;
 
 	LV2_Feature  **m_lv2_ui_features;
 
+	// Alternate UI instantiation stuff.
+	QLibrary      *m_lv2_ui_library;
+
+	const LV2UI_Descriptor *m_lv2_ui_descriptor;
+
+	LV2UI_Port_Map m_lv2_ui_port_map;
+	LV2_Feature    m_lv2_ui_port_map_feature;
+
+	// Common UI instantiation stuff.
+	LV2UI_Handle   m_lv2_ui_handle;
+	LV2UI_Widget   m_lv2_ui_widget;
+
+#ifdef CONFIG_LIBSUIL
 	SuilHost      *m_suil_host;
 	SuilInstance  *m_suil_instance;
-	SuilWidget     m_lv2_ui_widget;
-
-	LV2UI_Handle   m_lv2_ui_handle;
+#endif
 
 #ifdef CONFIG_LV2_ATOM
 
@@ -408,6 +450,7 @@ private:
 
 	EventFilter *m_pQtFilter;
 	QWidget     *m_pQtWidget;
+	bool         m_bQtDelete;
 
 	// Changed UI params hash-queue.
 	QHash<unsigned long, float> m_ui_params;
@@ -420,6 +463,17 @@ private:
 	// LV2 UI Show extension data interface.
 	const LV2UI_Show_Interface *m_lv2_ui_show_interface;
 #endif
+#if QT_VERSION >= 0x050100
+#ifdef CONFIG_LV2_UI_GTK2
+	struct _GtkWidget *m_pGtkWindow;
+	QWindow           *m_pQtWindow;
+#endif	// CONFIG_LV2_UI_GTK2
+#ifdef CONFIG_LV2_UI_X11
+	LV2UI_Resize m_lv2_ui_resize;
+	LV2_Feature  m_lv2_ui_resize_feature;
+	LV2_Feature  m_lv2_ui_parent_feature;
+#endif	// CONFIG_LV2_UI_X11
+#endif
 
 #endif	// CONFIG_LV2_UI
 
@@ -461,11 +515,16 @@ private:
 #ifdef CONFIG_LV2_OPTIONS
 #ifdef CONFIG_LV2_BUF_SIZE
 	LV2_Feature        m_lv2_options_feature;
-	LV2_Options_Option m_lv2_options[4];
+	LV2_Options_Option m_lv2_options[5];
 	uint32_t           m_iMinBlockLength;
 	uint32_t           m_iMaxBlockLength;
+	uint32_t           m_iNominalBlockLength;
 	uint32_t           m_iSequenceSize;
 #endif
+#ifdef CONFIG_LV2_UI
+	LV2_Feature        m_lv2_ui_options_feature;
+	LV2_Options_Option m_lv2_ui_options[2];
+#endif
 #endif
 };
 
