@@ -47,6 +47,7 @@ class qtractorTempoCursor;
 class qtractorMidiEditorForm;
 class qtractorMidiEditor;
 
+class qtractorActionControl;
 class qtractorMidiControlObserver;
 class qtractorSubject;
 
@@ -381,6 +382,9 @@ protected:
 
 	void setSongPos(unsigned short iSongPos);
 
+	unsigned long playHeadBackward() const;
+	unsigned long playHeadForward() const;
+
 	void updateSessionPre();
 	void updateSessionPost();
 
@@ -447,6 +451,7 @@ private:
 	QProgressBar *m_pProgressBar;
 	qtractorThumbView *m_pThumbView;
 	qtractorTempoCursor *m_pTempoCursor;
+	qtractorActionControl *m_pActionControl;
 	qtractorMidiControl *m_pMidiControl;
 	qtractorNsmClient *m_pNsmClient;
 	QString m_sNsmFile;
