@@ -1,7 +1,7 @@
 // qtractorMessages.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -83,6 +83,9 @@ protected:
 	// Just about to notify main-window that we're closing.
 	void closeEvent(QCloseEvent *);
 
+	// Set stdout/stderr blocking mode.
+	bool stdoutBlock(int fd, bool bBlock) const;
+
 protected slots:
 
 	// Stdout capture slot.
