@@ -1,7 +1,7 @@
 // qtractorMidiBuffer.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -330,6 +330,12 @@ public:
 	const Instruments& instruments() const
 		{ return m_instruments; }
 
+	// Direct MIDI controller helper.
+	void setController(unsigned short iChannel, int iController, int iValue);
+
+	// Shut-off MIDI channel (panic)...
+	void shutOff(unsigned short iChannel);
+
 protected:
 
 	// Audio output (de)activation methods.
