@@ -388,72 +388,6 @@ inline uint qHash ( const qtractorMidiControl::MapKey& key )
 }
 
 
-//----------------------------------------------------------------------------
-// qtractorMidiControlTypeGroup - MIDI control type/param widget group.
-
-#include "qtractorMidiEditor.h"
-
-// Forwrad decls.
-class QComboBox;
-class QLabel;
-
-
-class qtractorMidiControlTypeGroup : public QObject
-{
-	Q_OBJECT
-
-public:
-
-	// Constructor.
-	qtractorMidiControlTypeGroup(
-		qtractorMidiEditor *pMidiEditor,
-		QComboBox *pControlTypeComboBox,
-		QComboBox *pControlParamComboBox,
-		QLabel *pControlParamTextLabel = NULL);
-
-	// Accessors.
-	void setControlType(qtractorMidiControl::ControlType ctype);
-	qtractorMidiControl::ControlType controlType() const;
-	qtractorMidiControl::ControlType controlTypeFromIndex(int iIndex) const;
-
-	void setControlParam(unsigned short iParam);
-	unsigned short controlParam() const;
-	unsigned short controlParamFromIndex(int iIndex) const;
-
-	// Stabilizers.
-	void updateControlType(int iControlType = -1);
-
-signals:
-
-	void controlTypeChanged(int);
-	void controlParamChanged(int);
-
-protected slots:
-
-	void activateControlType(int);
-	void activateControlParam(int);
-
-	void editControlParamFinished();
-
-protected:
-
-	// Find combo-box indexes.
-	int indexFromControlType(qtractorMidiControl::ControlType ctype) const;
-	int indexFromControlParam(unsigned short iParam) const;
-
-private:
-
-	// Instance member variables.
-	qtractorMidiEditor *m_pMidiEditor;
-
-	QComboBox *m_pControlTypeComboBox;
-	QComboBox *m_pControlParamComboBox;
-	QLabel    *m_pControlParamTextLabel;
-
-	unsigned int m_iControlParamUpdate;
-};
-
-
 #endif  // __qtractorMidiControl_h
 
 // end of qtractorMidiControl.h
