@@ -1,7 +1,7 @@
 // qtractorMidiControlObserver.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -130,10 +130,9 @@ private:
 	bool m_bLatch;
 
 	// Tracking/catch-up members.
-	bool  m_bMidiValueInit;
-	bool  m_bMidiValueSync;
 	float m_fMidiValue;
-	
+	bool  m_bMidiSync;
+
 	// Special indirect automation relatives.
 	qtractorCurveList *m_pCurveList;
 };
