@@ -1,7 +1,7 @@
 // qtractorMidiEditCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -197,7 +197,7 @@ bool qtractorMidiEditCommand::execute ( bool bRedo )
 		}
 	}
 
-	// It's dirty, definitly...
+	// It's dirty, definitely...
 	m_pMidiClip->setDirtyEx(true);
 
 	// Have we changed on something less durable?
@@ -255,7 +255,7 @@ bool qtractorMidiEditCommand::adjust (void)
 	while (pEvent) {
 		qtractorMidiEvent *pNextEvent = pEvent->next();
 		// Whether event is (time) adjustable...
-		int key = int(pEvent->type()) << 7;
+		int key = int(pEvent->type()) << 14;
 		switch (pEvent->type()) {
 		case qtractorMidiEvent::NOTEON:
 		case qtractorMidiEvent::NOTEOFF:
@@ -263,6 +263,9 @@ bool qtractorMidiEditCommand::adjust (void)
 			key += int(pEvent->note());
 			break;
 		case qtractorMidiEvent::CONTROLLER:
+		case qtractorMidiEvent::REGPARAM:
+		case qtractorMidiEvent::NONREGPARAM:
+		case qtractorMidiEvent::CONTROL14:
 			key += int(pEvent->controller());
 			break;
 		case qtractorMidiEvent::CHANPRESS:
