@@ -21,10 +21,11 @@
 
 #include "qtractorAbout.h"
 #include "qtractorMidiEditorForm.h"
-#include "qtractorMidiEditor.h"
 #include "qtractorMidiEditView.h"
 #include "qtractorMidiEditEvent.h"
 
+#include "qtractorMidiControlTypeGroup.h"
+
 #include "qtractorMidiClip.h"
 #include "qtractorMidiEngine.h"
 #include "qtractorMidiMonitor.h"
@@ -135,8 +136,11 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 			SIGNAL(triggered(bool)),
 			SLOT(viewSnap()));
 		m_snapPerBeatActions.append(pAction);
-		addAction(pAction);
+		m_ui.viewSnapMenu->addAction(pAction);
 	}
+//	m_ui.viewSnapMenu->addSeparator();
+	m_ui.viewSnapMenu->addAction(m_ui.viewSnapZebraAction);
+	m_ui.viewSnapMenu->addAction(m_ui.viewSnapGridAction);
 
 	// Pre-fill the combo-boxes...
 	m_pSnapPerBeatComboBox->setIconSize(QSize(8, 16));
@@ -277,15 +281,6 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 	QObject::connect(m_ui.fileRecordExAction,
 		SIGNAL(triggered(bool)),
 		SLOT(fileRecordEx(bool)));
-	QObject::connect(m_ui.fileTrackInputsAction,
-		SIGNAL(triggered(bool)),
-		SLOT(fileTrackInputs()));
-	QObject::connect(m_ui.fileTrackOutputsAction,
-		SIGNAL(triggered(bool)),
-		SLOT(fileTrackOutputs()));
-	QObject::connect(m_ui.fileTrackPropertiesAction,
-		SIGNAL(triggered(bool)),
-		SLOT(fileTrackProperties()));
 	QObject::connect(m_ui.filePropertiesAction,
 		SIGNAL(triggered(bool)),
 		SLOT(fileProperties()));
@@ -295,6 +290,15 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 	QObject::connect(m_ui.fileLoopSetAction,
 		SIGNAL(triggered(bool)),
 		SLOT(fileLoopSet()));
+	QObject::connect(m_ui.fileTrackInputsAction,
+		SIGNAL(triggered(bool)),
+		SLOT(fileTrackInputs()));
+	QObject::connect(m_ui.fileTrackOutputsAction,
+		SIGNAL(triggered(bool)),
+		SLOT(fileTrackOutputs()));
+	QObject::connect(m_ui.fileTrackPropertiesAction,
+		SIGNAL(triggered(bool)),
+		SLOT(fileTrackProperties()));
 	QObject::connect(m_ui.fileCloseAction,
 		SIGNAL(triggered(bool)),
 		SLOT(fileClose()));
@@ -607,6 +611,8 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 		QObject::connect(m_ui.transportPanicAction,
 			SIGNAL(triggered(bool)),
 			pMainForm, SLOT(transportPanic()));
+		// Add to main editors list...
+		pMainForm->addEditorForm(this);
 	}
 
 	// Finally set initial editor type-params...
@@ -628,6 +634,11 @@ qtractorMidiEditorForm::qtractorMidiEditorForm (
 // Destructor.
 qtractorMidiEditorForm::~qtractorMidiEditorForm (void)
 {
+	// Remove this one from main-form list...
+	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->removeEditorForm(this);
+
 	// View/Snap-to-beat actions termination...
 	qDeleteAll(m_snapPerBeatActions);
 	m_snapPerBeatActions.clear();
@@ -692,17 +703,6 @@ int qtractorMidiEditorForm::querySave ( const QString& sFilename )
 }
 
 
-// On-show event handler.
-void qtractorMidiEditorForm::showEvent ( QShowEvent *pShowEvent )
-{
-	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm)
-		pMainForm->addEditorForm(this);
-
-	QMainWindow::showEvent(pShowEvent);
-}
-
-
 // On-close event handler.
 void qtractorMidiEditorForm::closeEvent ( QCloseEvent *pCloseEvent )
 {
@@ -754,11 +754,6 @@ void qtractorMidiEditorForm::closeEvent ( QCloseEvent *pCloseEvent )
 		}
 	}
 
-	// Remove this one from main-form list...
-	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm)
-		pMainForm->removeEditorForm(this);
-
 	// Close it good.
 	pCloseEvent->accept();
 }
@@ -771,26 +766,13 @@ void qtractorMidiEditorForm::closeEvent ( QCloseEvent *pCloseEvent )
 void qtractorMidiEditorForm::contextMenuEvent (
 	QContextMenuEvent *pContextMenuEvent )
 {
-	QMenu menu(this);
+	stabilizeForm();
 
-	menu.addAction(m_ui.editUndoAction);
-	menu.addAction(m_ui.editRedoAction);
-	menu.addSeparator();
-	menu.addAction(m_ui.editCutAction);
-	menu.addAction(m_ui.editCopyAction);
-	menu.addAction(m_ui.editPasteAction);
-	menu.addAction(m_ui.editPasteRepeatAction);
-	menu.addSeparator();
-	menu.addAction(m_ui.editDeleteAction);
-	menu.addSeparator();
-	menu.addMenu(m_ui.editModeMenu);
-	menu.addMenu(m_ui.editSelectMenu);
-	menu.addSeparator();
-	menu.addMenu(m_ui.toolsMenu);
-
-	menu.exec(pContextMenuEvent->globalPos());
+	// Primordial edit menu should be available...
+	m_ui.editMenu->exec(pContextMenuEvent->globalPos());
 }
 
+
 // Edit menu accessor.
 QMenu *qtractorMidiEditorForm::editMenu (void) const
 {
@@ -1628,7 +1610,8 @@ void qtractorMidiEditorForm::helpShortcuts (void)
 		return;
 
 	qtractorShortcutForm shortcutForm(findChildren<QAction *> (), this);
-	if (shortcutForm.exec())
+	shortcutForm.setActionControl(NULL); // Disable MIDI Controllers here!
+	if (shortcutForm.exec() && shortcutForm.isDirtyActionShortcuts())
 		pOptions->saveActionShortcuts(this);
 }
 
