@@ -30,6 +30,7 @@
 #include <alsa/asoundlib.h>
 
 #include <QHash>
+#include <QObject>
 
 // Forward declarations.
 class qtractorMidiBus;
@@ -123,6 +124,9 @@ public:
 	void resetAllControllers(bool bForceImmediate);
 	bool isResetAllControllers() const;
 
+	// Shut-off all MIDI buses (stop)...
+	void shutOffAllBuses(bool bClose = false) const;
+
 	// Shut-off all MIDI tracks (panic)...
 	void shutOffAllTracks() const;
 
@@ -416,6 +420,9 @@ public:
 	{
 		// Default payload constructor.
 		Patch() : bankSelMethod(-1), bank(-1), prog(-1) {}
+		// Validate members.
+		bool isValid() const
+			{ return bankSelMethod >= 0 && (bank >= 0 || prog >= 0); }
 		// Payload members.
 		QString instrumentName;
 		int     bankSelMethod;
@@ -423,8 +430,8 @@ public:
 		int     prog;
 	};
 
-	// Channel patch map accessor.
-	Patch& patch(unsigned short iChannel)
+	// Channel patch map accessors.
+	const Patch& patch(unsigned iChannel)
 		{ return m_patches[iChannel & 0x0f]; }
 
 	// Direct MIDI bank/program selection helper.
@@ -501,8 +508,9 @@ protected:
 	void setControllerEx(unsigned short iChannel, int iController,
 		int iValue = 0, qtractorTrack *pTrack = NULL) const;
 
-	// Bus mode change event.
+	// Bus mode/name change events.
 	void updateBusMode();
+	void updateBusName();
 
 	// Create plugin-list properly.
 	qtractorPluginList *createPluginList(int iFlags) const;
