@@ -1,7 +1,7 @@
 // qtractorMidiSysexForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -215,10 +215,13 @@ void qtractorMidiSysexForm::importSlot (void)
 	filters.append(tr("All files (*.*)"));
 	const QString& sTitle  = tr("Import SysEx Files") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = filters.join(";;");
-#if 0//QT_VERSION < 0x040400
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to open...
+	QFileDialog::Options options = 0;
+	if (pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	files = QFileDialog::getOpenFileNames(this,
-		sTitle, pOptions->sMidiSysexDir, sFilter);
+		sTitle, pOptions->sMidiSysexDir, sFilter, NULL, options);
 #else
 	// Construct open-files dialog...
 	QFileDialog fileDialog(this,
@@ -232,6 +235,8 @@ void qtractorMidiSysexForm::importSlot (void)
 	urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(pOptions->sMidiSysexDir));
 	fileDialog.setSidebarUrls(urls);
+	if (pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		files = fileDialog.selectedFiles();
@@ -286,10 +291,13 @@ void qtractorMidiSysexForm::exportSlot (void)
 	const QString  sExt("syx");
 	const QString& sTitle  = tr("Export SysEx File") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = tr("SysEx files (*.%1)").arg(sExt);
-#if 0// QT_VERSION < 0x040400
+#if 1// QT_VERSION < 0x040400
 	// Ask for the filename to open...
+	QFileDialog::Options options = 0;
+	if (pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	sPath = QFileDialog::getSaveFileName(this,
-		sTitle, pOptions->sMidiSysexDir, sFilter);
+		sTitle, pOptions->sMidiSysexDir, sFilter, NULL, options);
 #else
 	// Construct open-files dialog...
 	QFileDialog fileDialog(this,
@@ -303,6 +311,8 @@ void qtractorMidiSysexForm::exportSlot (void)
 	urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(pOptions->sMidiSysexDir));
 	fileDialog.setSidebarUrls(urls);
+	if (pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		sPath = fileDialog.selectedFiles().first();
@@ -420,10 +430,13 @@ void qtractorMidiSysexForm::openSlot (void)
 	const QString  sExt("syx");
 	const QString& sTitle  = tr("Open SysEx") + " - " QTRACTOR_TITLE;
 	const QString& sFilter = tr("SysEx files (*.%1)").arg(sExt);
-#if 0//QT_VERSION < 0x040400
+#if 1//QT_VERSION < 0x040400
 	// Ask for the filename to save...
+	QFileDialog::Options options = 0;
+	if (pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
 	sFilename = QFileDialog::getOpenFileName(this,
-		sTitle, pOptions->sMidiSysexDir, sFilter);
+		sTitle, pOptions->sMidiSysexDir, sFilter, NULL, options);
 #else
 	// Construct save-file dialog...
 	QFileDialog fileDialog(this,
@@ -437,6 +450,8 @@ void qtractorMidiSysexForm::openSlot (void)
 	urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 	urls.append(QUrl::fromLocalFile(pOptions->sMidiSysexDir));
 	fileDialog.setSidebarUrls(urls);
+	if (pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (fileDialog.exec())
 		sFilename = fileDialog.selectedFiles().first();
@@ -485,10 +500,14 @@ void qtractorMidiSysexForm::saveSlot (void)
 	if (!fi.exists()) {
 		const QString& sTitle  = tr("Save SysEx") + " - " QTRACTOR_TITLE;
 		const QString& sFilter = tr("Sysex files (*.%1)").arg(sExt);
-	#if 0//QT_VERSION < 0x040400
+	#if 1//QT_VERSION < 0x040400
 		// Ask for the filename to save...
+		qtractorOptions *pOptions = qtractorOptions::getInstance();
+		QFileDialog::Options options = 0;
+		if (pOptions->bDontUseNativeDialogs)
+			options |= QFileDialog::DontUseNativeDialog;
 		sFilename = QFileDialog::getSaveFileName(this,
-			sTitle, sFilename, sFilter);
+			sTitle, sFilename, sFilter, NULL, options);
 	#else
 		// Construct save-file dialog...
 		QFileDialog fileDialog(this,
@@ -502,6 +521,8 @@ void qtractorMidiSysexForm::saveSlot (void)
 		urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
 		urls.append(QUrl::fromLocalFile(pOptions->sMidiSysexDir));
 		fileDialog.setSidebarUrls(urls);
+		if (pOptions->bDontUseNativeDialogs)
+			fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 		// Show dialog...
 		if (fileDialog.exec())
 			sFilename = fileDialog.selectedFiles().first();
