@@ -111,11 +111,6 @@ void qtractorMonitorButton::setTrack ( qtractorTrack *pTrack )
 	updateMonitor(); // Visitor setup.
 }
 
-qtractorTrack *qtractorMonitorButton::track (void) const
-{
-	return m_pTrack;
-}
-
 
 // Specific bus accessors.
 void qtractorMonitorButton::setBus ( qtractorBus *pBus )
@@ -128,11 +123,6 @@ void qtractorMonitorButton::setBus ( qtractorBus *pBus )
 	updateMonitor(); // Visitor setup.
 }
 
-qtractorBus *qtractorMonitorButton::bus (void) const
-{
-	return m_pBus;
-}
-
 
 // Visitors overload.
 void qtractorMonitorButton::updateValue ( float fValue )
@@ -575,18 +565,6 @@ void qtractorMixerStrip::updateMidiLabel (void)
 }
 
 
-// Child accessors.
-qtractorPluginListView *qtractorMixerStrip::pluginListView (void) const
-{
-	return m_pPluginListView;
-}
-
-qtractorMeter *qtractorMixerStrip::meter (void) const
-{
-	return m_pMeter;
-}
-
-
 // Mixer strip clear/suspend delegates
 void qtractorMixerStrip::clear (void)
 {
@@ -649,11 +627,6 @@ void qtractorMixerStrip::setBus ( qtractorBus *pBus )
 	updateName();
 }
 
-qtractorBus *qtractorMixerStrip::bus (void) const
-{
-	return m_pBus;
-}
-
 
 // Track property accessors.
 void qtractorMixerStrip::setTrack ( qtractorTrack *pTrack )
@@ -679,11 +652,6 @@ void qtractorMixerStrip::setTrack ( qtractorTrack *pTrack )
 	updateName();
 }
 
-qtractorTrack *qtractorMixerStrip::track (void) const
-{
-	return m_pTrack;
-}
-
 
 // Selection methods.
 void qtractorMixerStrip::setSelected ( bool bSelected )
@@ -743,11 +711,6 @@ void qtractorMixerStrip::setSelected ( bool bSelected )
 #endif
 }
 
-bool qtractorMixerStrip::isSelected (void) const
-{
-	return m_bSelected;
-}
-
 
 // Strip refreshment.
 void qtractorMixerStrip::refresh (void)
@@ -756,17 +719,6 @@ void qtractorMixerStrip::refresh (void)
 }
 
 
-// Hacko-list-management marking...
-void qtractorMixerStrip::setMark ( int iMark )
-{
-	m_iMark = iMark;
-}
-
-int qtractorMixerStrip::mark (void) const
-{
-	return m_iMark;
-}
-
 // Mouse selection event handlers.
 void qtractorMixerStrip::mousePressEvent ( QMouseEvent *pMouseEvent )
 {
@@ -895,53 +847,6 @@ void qtractorMixerStrip::gainChangedSlot ( float fGain )
 }
 
 
-//----------------------------------------------------------------------------
-// qtractorMixerRackWidget -- Mixer strip rack widget decl.
-
-class qtractorMixerRackWidget : public QScrollArea
-{
-public:
-
-	// Constructor.
-	qtractorMixerRackWidget(qtractorMixerRack *pRack);
-	// Default destructor.
-	~qtractorMixerRackWidget();
-
-	// The mixer strip workspace widget.
-	QWidget *workspace() const;
-
-	// Add/remove a mixer strip to/from rack workspace.
-	void addStrip(qtractorMixerStrip *pStrip);
-	void removeStrip( qtractorMixerStrip *pStrip);
-
-	// Multi-row workspace layout method.
-	void updateWorkspace();
-
-protected:
-
-	// Resize event handler.
-	void resizeEvent(QResizeEvent *);
-
-	// Context menu request event handler.
-	void contextMenuEvent(QContextMenuEvent *);
-
-	// Mouse click event handler.
-	void mousePressEvent(QMouseEvent *);
-
-	// Initial minimum widget extents.
-	QSize sizeHint() const;
-
-private:
-
-	// Instance variables.
-	qtractorMixerRack *m_pRack;
-
-	// Layout widgets.
-	QGridLayout *m_pWorkspaceLayout;
-	QWidget     *m_pWorkspaceWidget;
-};
-
-
 //----------------------------------------------------------------------------
 // qtractorMixerRackWidget -- Meter bridge rack widget impl.
 
@@ -986,13 +891,6 @@ void qtractorMixerRackWidget::removeStrip ( qtractorMixerStrip *pStrip )
 }
 
 
-// The strip workspace widget.
-QWidget *qtractorMixerRackWidget::workspace (void) const
-{
-	return m_pWorkspaceWidget;
-}
-
-
 // Resize event handler.
 void qtractorMixerRackWidget::resizeEvent ( QResizeEvent *pResizeEvent )
 {
@@ -1059,13 +957,6 @@ void qtractorMixerRackWidget::mousePressEvent ( QMouseEvent *pMouseEvent )
 }
 
 
-// Initial minimum widget extents.
-QSize qtractorMixerRackWidget::sizeHint (void) const
-{
-	return QSize(160, 320);
-}
-
-
 // Multi-row workspace layout method.
 void qtractorMixerRackWidget::updateWorkspace (void)
 {
@@ -1087,15 +978,15 @@ void qtractorMixerRackWidget::updateWorkspace (void)
 		int wth = 0;
 		for (int i = 0; i < nitems; ++i) {
 			QLayoutItem *item = items[i];
+			m_pWorkspaceLayout->addItem(item, row, col++);
 			if (bAutoGridLayout) {
-				wth += item->sizeHint().width();
-				if (wth > w && row < nrows && col > ncols) {
+				const int wi = item->sizeHint().width(); wth += wi;
+				if (wth > (w - wi) && row < nrows && col > ncols) {
 					wth = 0;
 					col = 0;
 					++row;
 				}
 			}
-			m_pWorkspaceLayout->addItem(item, row, col++);
 		}
 	}
 
@@ -1139,7 +1030,6 @@ public:
 
 
 
-
 //----------------------------------------------------------------------------
 // qtractorMixerRack -- Mixer strip rack.
 
@@ -1174,19 +1064,6 @@ qtractorMixerRack::~qtractorMixerRack (void)
 }
 
 
-// The main mixer widget accessor.
-qtractorMixer *qtractorMixerRack::mixer (void) const
-{
-	return m_pMixer;
-}
-
-
-// The mixer strip workspace widget accessor.
-QWidget *qtractorMixerRack::workspace (void) const
-{
-	return m_pRackWidget->workspace();
-}
-
 // The mixer strip workspace methods.
 void qtractorMixerRack::ensureVisible ( int x, int y, int xm, int ym )
 {
@@ -1250,13 +1127,6 @@ void qtractorMixerRack::updateStrip (
 }
 
 
-// Current strip count.
-int qtractorMixerRack::stripCount (void) const
-{
-	return m_strips.count();
-}
-
-
 // Complete rack refreshment.
 void qtractorMixerRack::refresh (void)
 {
@@ -1289,11 +1159,6 @@ void qtractorMixerRack::setSelectEnabled ( bool bSelectEnabled )
 	}
 }
 
-bool qtractorMixerRack::isSelectEnabled (void) const
-{
-	return m_bSelectEnabled;
-}
-
 
 void qtractorMixerRack::setSelectedStrip ( qtractorMixerStrip *pStrip )
 {
@@ -1307,12 +1172,6 @@ void qtractorMixerRack::setSelectedStrip ( qtractorMixerStrip *pStrip )
 	}
 }
 
-qtractorMixerStrip *qtractorMixerRack::selectedStrip (void) const
-{
-	return m_pSelectedStrip;
-}
-
-
 
 // Hacko-list-management marking...
 void qtractorMixerRack::markStrips ( int iMark )
@@ -1391,13 +1250,6 @@ void qtractorMixerRack::busPropertiesSlot (void)
 }
 
 
-// Multi-row workspace layout method.
-void qtractorMixerRack::updateWorkspace (void)
-{
-	m_pRackWidget->updateWorkspace();
-}
-
-
 //----------------------------------------------------------------------------
 // qtractorMixer -- Mixer widget.
 
@@ -1510,30 +1362,6 @@ void qtractorMixer::saveMixerState (void)
 }
 
 
-// Initial minimum widget extents.
-QSize qtractorMixer::sizeHint (void) const
-{
-	return QSize(480, 320);
-}
-
-
-// The mixer strips rack accessors.
-qtractorMixerRack *qtractorMixer::inputRack (void) const
-{
-	return m_pInputRack;
-}
-
-qtractorMixerRack *qtractorMixer::trackRack (void) const
-{
-	return m_pTrackRack;
-}
-
-qtractorMixerRack *qtractorMixer::outputRack (void) const
-{
-	return m_pOutputRack;
-}
-
-
 // Update mixer rack, checking if given monitor already exists.
 void qtractorMixer::updateBusStrip ( qtractorMixerRack *pRack,
 	qtractorBus *pBus, qtractorBus::BusMode busMode, bool bReset )
