@@ -45,6 +45,7 @@ class qtractorPluginListView;
 
 class QHBoxLayout;
 class QVBoxLayout;
+class QGridLayout;
 
 class QPushButton;
 class QLabel;
@@ -65,11 +66,13 @@ public:
 
 	// Specific track accessors.
 	void setTrack(qtractorTrack *pTrack);
-	qtractorTrack *track() const;
+	qtractorTrack *track() const
+		{ return m_pTrack; }
 
 	// Specific bus accessors.
 	void setBus(qtractorBus *pBus);
-	qtractorBus *bus() const;
+	qtractorBus *bus() const
+		{ return m_pBus; }
 
 protected slots:
 
@@ -120,27 +123,34 @@ public:
 	qtractorMonitor *monitor() const;
 
 	// Child accessors.
-	qtractorPluginListView *pluginListView() const;
-	qtractorMeter *meter() const;
+	qtractorPluginListView *pluginListView() const
+		{ return m_pPluginListView; }
+	qtractorMeter *meter() const
+		{ return m_pMeter; }
 
 	// Bus property accessors.
 	void setBus(qtractorBus *pBus);
-	qtractorBus *bus() const;
+	qtractorBus *bus() const
+		{ return m_pBus; }
 
 	// Track property accessors.
 	void setTrack(qtractorTrack *pTrack);
-	qtractorTrack *track() const;
+	qtractorTrack *track() const
+		{ return m_pTrack; }
 
 	// Selection methods.
 	void setSelected(bool bSelected);
-	bool isSelected() const;
+	bool isSelected() const
+		{ return m_bSelected; }
 
 	// Strip refreshment.
 	void refresh();
 
 	// Hacko-list-management marking...
-	void setMark(int iMark);
-	int mark() const;
+	void setMark(int iMark)
+		{ m_iMark = iMark; }
+	int mark() const
+		{ return m_iMark; }
 
 	// Special bus dispatchers.
 	void busConnections(qtractorBus::BusMode busMode);
@@ -205,6 +215,57 @@ private:
 };
 
 
+//----------------------------------------------------------------------------
+// qtractorMixerRackWidget -- Mixer strip rack widget decl.
+
+class qtractorMixerRackWidget : public QScrollArea
+{
+	Q_OBJECT
+
+public:
+
+	// Constructor.
+	qtractorMixerRackWidget(qtractorMixerRack *pRack);
+	// Default destructor.
+	~qtractorMixerRackWidget();
+
+	// The mixer strip workspace widget.
+	QWidget *workspace() const
+		{ return m_pWorkspaceWidget; }
+
+	// Add/remove a mixer strip to/from rack workspace.
+	void addStrip(qtractorMixerStrip *pStrip);
+	void removeStrip( qtractorMixerStrip *pStrip);
+
+	// Multi-row workspace layout method.
+	void updateWorkspace();
+
+protected:
+
+	// Resize event handler.
+	void resizeEvent(QResizeEvent *);
+
+	// Context menu request event handler.
+	void contextMenuEvent(QContextMenuEvent *);
+
+	// Mouse click event handler.
+	void mousePressEvent(QMouseEvent *);
+
+	// Initial minimum widget extents.
+	QSize sizeHint() const
+		{ return QSize(160, 320); }
+
+private:
+
+	// Instance variables.
+	qtractorMixerRack *m_pRack;
+
+	// Layout widgets.
+	QGridLayout *m_pWorkspaceLayout;
+	QWidget     *m_pWorkspaceWidget;
+};
+
+
 //----------------------------------------------------------------------------
 // qtractorMixerRack -- Mixer strip rack.
 
@@ -220,10 +281,12 @@ public:
 	~qtractorMixerRack();
 
 	// The main mixer widget accessor.
-	qtractorMixer *mixer() const;
+	qtractorMixer *mixer() const
+		{ return m_pMixer; }
 
 	// The mixer strip workspace widget accessor.
-	QWidget *workspace() const;
+	QWidget *workspace() const
+		{ return m_pRackWidget->workspace(); }
 
 	// The mixer strip workspace methods.
 	void ensureVisible(int x, int y, int xm, int ym);
@@ -239,7 +302,8 @@ public:
 	void updateStrip(qtractorMixerStrip *pStrip, qtractorMonitor *pMonitor);
 
 	// Current Strip count.
-	int stripCount() const;
+	int stripCount() const
+		{ return m_strips.count(); }
 
 	// Complete rack refreshment.
 	void refresh();
@@ -249,17 +313,20 @@ public:
 
 	// Selection stuff.
 	void setSelectEnabled(bool bSelectEnabled);
-	bool isSelectEnabled() const;
+	bool isSelectEnabled() const
+		{ return m_bSelectEnabled; }
 
 	void setSelectedStrip(qtractorMixerStrip *pStrip);
-	qtractorMixerStrip *selectedStrip() const;
+	qtractorMixerStrip *selectedStrip() const
+		{ return m_pSelectedStrip; }
 
 	// Hacko-list-management marking...
 	void markStrips(int iMark);
 	void cleanStrips(int iMark);
 
 	// Multi-row workspace layout method.
-	void updateWorkspace();
+	void updateWorkspace()
+		{ m_pRackWidget->updateWorkspace(); }
 
 public slots:
 
@@ -297,6 +364,8 @@ private:
 
 class qtractorMixer : public QMainWindow
 {
+	Q_OBJECT
+
 public:
 
 	// Constructor.
@@ -305,10 +374,13 @@ public:
 	~qtractorMixer();
 
 	// The mixer strips rack accessors.
-	qtractorMixerRack *inputRack()  const;
-	qtractorMixerRack *trackRack()  const;
-	qtractorMixerRack *outputRack() const;
-	
+	qtractorMixerRack *inputRack() const
+		{ return m_pInputRack; }
+	qtractorMixerRack *trackRack() const
+		{ return m_pTrackRack; }
+	qtractorMixerRack *outputRack() const
+		{ return m_pOutputRack; }
+
 	// Update buses and tracks'racks.
 	void updateBuses(bool bReset = false);
 	void updateTracks(bool bReset = false);
@@ -344,7 +416,8 @@ protected:
 	void saveMixerState();
 
 	// Initial minimum widget extents.
-	QSize sizeHint() const;
+	QSize sizeHint() const
+		{ return QSize(480, 320); }
 
 private:
 
