@@ -1,7 +1,7 @@
 // qtractorMmcEvent.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -47,15 +47,15 @@ unsigned long qtractorMmcEvent::locate (void) const
 float qtractorMmcEvent::shuttle (void) const
 {
 	float fShuttle = 0.0f;
-	unsigned char *data = (unsigned char *) m_data.constData();
 
 	if (m_cmd == SHUTTLE && m_data.length() > 2) {
-		unsigned char sh = data[0];
-		unsigned char sm = data[1];
-		unsigned char sl = data[2];
-		unsigned int  n  = (sh & 0x38);
-		unsigned int  p  = ((sh & 0x07) << n) | (sm >> (7 - n));
-		unsigned int  q  = ((sm << n) << 7) | sl;
+		const unsigned char *data = (const unsigned char *) m_data.constData();
+		const unsigned char sh = data[0];
+		const unsigned char sm = data[1];
+		const unsigned char sl = data[2];
+		const unsigned int  n  = (sh & 0x38);
+		const unsigned int  p  = ((sh & 0x07) << n) | (sm >> (7 - n));
+		const unsigned int  q  = ((sm << n) << 7) | sl;
 		fShuttle = float(p) + float(q) / (1 << (14 - n));
 		if (sh & 0x40)
 			fShuttle = -(fShuttle);
@@ -69,9 +69,9 @@ float qtractorMmcEvent::shuttle (void) const
 int qtractorMmcEvent::step (void) const
 {
 	int iStep = 0;
-	unsigned char *data = (unsigned char *) m_data.constData();
 
 	if (m_cmd == STEP && m_data.length() > 0) {
+		const unsigned char *data = (const unsigned char *) m_data.constData();
 		iStep = (data[0] & 0x3f);
 		if (data[0] & 0x40)
 			iStep = -(iStep);
@@ -85,10 +85,11 @@ int qtractorMmcEvent::step (void) const
 qtractorMmcEvent::SubCommand qtractorMmcEvent::scmd (void) const
 {
 	SubCommand scmd = TRACK_NONE;
-	unsigned char *data = (unsigned char *) m_data.constData();
 
-	if (m_cmd == MASKED_WRITE && m_data.length() > 3)
+	if (m_cmd == MASKED_WRITE && m_data.length() > 3) {
+		const unsigned char *data = (const unsigned char *) m_data.constData();
 		scmd = SubCommand(data[0]);
+	}
 
 	return scmd;
 }
@@ -96,12 +97,12 @@ qtractorMmcEvent::SubCommand qtractorMmcEvent::scmd (void) const
 int qtractorMmcEvent::track (void) const
 {
 	int iTrack = 0;
-	unsigned char *data = (unsigned char *) m_data.constData();
 
 	if (m_cmd == MASKED_WRITE && m_data.length() > 3) {
+		const unsigned char *data = (unsigned char *) m_data.constData();
 		iTrack = (data[1] > 0 ? (data[1] * 7) : 0) - 5;
 		for (int i = 0; i < 7; ++i) {
-			int iMask = (1 << i);
+			const int iMask = (1 << i);
 			if (data[2] & iMask)
 				break;
 			++iTrack;
@@ -114,11 +115,11 @@ int qtractorMmcEvent::track (void) const
 bool qtractorMmcEvent::isOn (void) const
 {
 	bool bOn = false;
-	unsigned char *data = (unsigned char *) m_data.constData();
 
 	if (m_cmd == MASKED_WRITE && m_data.length() > 3) {
+		const unsigned char *data = (unsigned char *) m_data.constData();
 		for (int i = 0; i < 7; ++i) {
-			int iMask = (1 << i);
+			const int iMask = (1 << i);
 			if (data[2] & iMask) {
 				bOn = (data[3] & iMask);
 				break;
