@@ -1,7 +1,7 @@
 // qtractorObserver.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,6 +25,9 @@
 #include <QString>
 #include <QList>
 
+#include <math.h>
+
+
 // Forward declarations.
 class qtractorSubject;
 class qtractorObserver;
@@ -105,6 +108,16 @@ public:
 	bool isToggled() const
 		{ return m_bToggled; }
 
+	// Integer mode accessors.
+	void setInteger(bool bInteger)
+		{ m_bInteger = bInteger; }
+	bool isInteger() const
+		{ return m_bInteger; }
+
+	// Non toggled nor integer mode helper.
+	bool isDecimal() const
+		{ return !m_bToggled && !m_bInteger; }
+
 	// Filter value within legal bounds.
 	float safeValue (float fValue) const
 	{
@@ -118,6 +131,9 @@ public:
 		else
 		if (fValue < m_fMinValue)
 			fValue = m_fMinValue;
+		else
+		if (m_bInteger)
+			fValue = ::roundf(fValue);
 
 		return fValue;
 	}
@@ -139,6 +155,7 @@ public:
 	
 	// Queue reset (clear).
 	static void resetQueue();
+	static void clearQueue();
 
 private:
 
@@ -161,6 +178,9 @@ private:
 	// Toggled value mode (max or min).
 	bool    m_bToggled;
 
+	// Integer value mode.
+	bool    m_bInteger;
+
 	// Automation curve association.
 	qtractorCurve *m_pCurve;
 
@@ -231,6 +251,14 @@ public:
 	bool isToggled() const
 		{ return (m_pSubject ? m_pSubject->isToggled() : false); }
 
+	// Integer mode accessors.
+	bool isInteger() const
+		{ return (m_pSubject ? m_pSubject->isInteger() : false); }
+
+	// Non toggled nor integer mode helper.
+	bool isDecimal() const
+		{ return (m_pSubject ? m_pSubject->isDecimal() : false); }
+
 	// Filter value within legal bounds.
 	float safeValue(float fValue) const
 		{ return (m_pSubject ? m_pSubject->safeValue(fValue) : 0.0f); }
