@@ -738,25 +738,35 @@ void qtractorOptions::loadWidgetGeometry ( QWidget *pWidget, bool bVisible )
 {
 	// Try to restore old form window positioning.
 	if (pWidget) {
+	//	if (bVisible) pWidget->show(); -- force initial exposure?
+		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
+	#if QT_VERSION >= 0x050000
+		const QByteArray& geometry
+			= m_settings.value("/geometry").toByteArray();
+		if (!geometry.isEmpty())
+			pWidget->restoreGeometry(geometry);
+		else
+	#else//--LOAD_OLD_GEOMETRY
 		QPoint wpos;
 		QSize  wsize;
-		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
 		wpos.setX(m_settings.value("/x", -1).toInt());
 		wpos.setY(m_settings.value("/y", -1).toInt());
 		wsize.setWidth(m_settings.value("/width", -1).toInt());
 		wsize.setHeight(m_settings.value("/height", -1).toInt());
-		if (!bVisible) bVisible = m_settings.value("/visible", false).toBool();
-		m_settings.endGroup();
 		if (wpos.x() > 0 && wpos.y() > 0)
 			pWidget->move(wpos);
 		if (wsize.width() > 0 && wsize.height() > 0)
 			pWidget->resize(wsize);
-	//	else
-	//		pWidget->adjustSize();
+		else
+	#endif
+		pWidget->adjustSize();
+		if (!bVisible)
+			bVisible = m_settings.value("/visible", false).toBool();
 		if (bVisible)
 			pWidget->show();
-	//	else
-	//		pWidget->hide();
+		else
+			pWidget->hide();
+		m_settings.endGroup();
 	}
 }
 
@@ -768,13 +778,17 @@ void qtractorOptions::saveWidgetGeometry ( QWidget *pWidget, bool bVisible )
 	// only save the form geometry while its up and visible)
 	if (pWidget) {
 		m_settings.beginGroup("/Geometry/" + pWidget->objectName());
+	#if QT_VERSION >= 0x050000
+		m_settings.setValue("/geometry", pWidget->saveGeometry());
+	#else//--SAVE_OLD_GEOMETRY
 		const QPoint& wpos  = pWidget->pos();
 		const QSize&  wsize = pWidget->size();
-		if (!bVisible) bVisible = pWidget->isVisible();
 		m_settings.setValue("/x", wpos.x());
 		m_settings.setValue("/y", wpos.y());
 		m_settings.setValue("/width", wsize.width());
 		m_settings.setValue("/height", wsize.height());
+	#endif
+		if (!bVisible) bVisible = pWidget->isVisible();
 		m_settings.setValue("/visible", bVisible);
 		m_settings.endGroup();
 	}
@@ -886,21 +900,25 @@ void qtractorOptions::saveSplitterSizes ( QSplitter *pSplitter )
 
 
 //---------------------------------------------------------------------------
-// Action shortcut persistence helper methos.
+// Action shortcut persistence helper methods.
+
 void qtractorOptions::loadActionShortcuts ( QObject *pObject )
 {
 	m_settings.beginGroup("/Shortcuts/" + pObject->objectName());
 
-	QList<QAction *> actions = pObject->findChildren<QAction *> ();
-	QListIterator<QAction *> iter(actions);
+	const QStringList& keys = m_settings.childKeys();
+	QStringListIterator iter(keys);
 	while (iter.hasNext()) {
-		QAction *pAction = iter.next();
-		if (pAction->objectName().isEmpty())
+		const QString& sObjectName = iter.next();
+		const QList<QAction *>& actions
+			= pObject->findChildren<QAction *> (sObjectName);
+		if (actions.isEmpty())
 			continue;
-		const QString& sKey = '/' + pAction->objectName();
-		const QString& sValue = m_settings.value('/' + sKey).toString();
+		const QString& sKey = '/' + sObjectName;
+		const QString& sValue = m_settings.value(sKey).toString();
 		if (sValue.isEmpty())
 			continue;
+		QAction *pAction = actions.first();
 		pAction->setShortcut(QKeySequence(sValue));
 	}
 
@@ -931,4 +949,107 @@ void qtractorOptions::saveActionShortcuts ( QObject *pObject )
 }
 
 
+//---------------------------------------------------------------------------
+// Action MIDI observers persistence helper methods.
+
+#include "qtractorActionControl.h"
+
+void qtractorOptions::loadActionControl ( QObject *pObject )
+{
+	qtractorActionControl *pActionControl
+		= qtractorActionControl::getInstance();
+	if (pActionControl == NULL)
+		return;
+
+	qtractorMidiControl *pMidiControl
+		= qtractorMidiControl::getInstance();
+	if (pMidiControl == NULL)
+		return;
+
+	pActionControl->clear();
+
+	m_settings.beginGroup("/MidiObservers/" + pObject->objectName());
+
+	const QStringList& keys = m_settings.childKeys();
+	QStringListIterator iter(keys);
+	while (iter.hasNext()) {
+		const QString& sObjectName = iter.next();
+		const QList<QAction *>& actions
+			= pObject->findChildren<QAction *> (sObjectName);
+		if (actions.isEmpty())
+			continue;
+		const QString& sKey = '/' + sObjectName;
+		const QList<QVariant>& vlist
+			= m_settings.value(sKey).toList();
+		if (vlist.count() < 6)
+			continue;
+		QAction *pAction = actions.first();
+		qtractorActionControl::MidiObserver *pMidiObserver
+			= pActionControl->addMidiObserver(pAction);
+		if (pMidiObserver) {
+			pMidiObserver->setType(
+				qtractorMidiControl::typeFromText(vlist.at(0).toString()));
+			pMidiObserver->setChannel(vlist.at(1).toInt());
+			pMidiObserver->setParam(vlist.at(2).toInt());
+			pMidiObserver->setFeedback(vlist.at(3).toBool());
+			pMidiObserver->setInvert(vlist.at(4).toBool());
+			pMidiObserver->setHook(vlist.at(5).toBool());
+			pMidiObserver->setLatch(vlist.at(6).toBool());
+			pMidiControl->mapMidiObserver(pMidiObserver);
+		}
+	}
+
+	m_settings.endGroup();
+}
+
+
+void qtractorOptions::saveActionControl ( QObject *pObject )
+{
+	qtractorActionControl *pActionControl
+		= qtractorActionControl::getInstance();
+	if (pActionControl == NULL)
+		return;
+
+	qtractorMidiControl *pMidiControl
+		= qtractorMidiControl::getInstance();
+	if (pMidiControl == NULL)
+		return;
+
+	m_settings.beginGroup("/MidiObservers/" + pObject->objectName());
+
+	const QStringList& keys = m_settings.childKeys();
+	QStringListIterator iter(keys);
+	while (iter.hasNext()) {
+		const QString& key = iter.next();
+		m_settings.remove(key);
+	}
+
+	const qtractorActionControl::MidiObservers& midiObservers
+		= pActionControl->midiObservers();
+	qtractorActionControl::MidiObservers::ConstIterator midi_iter
+		= midiObservers.constBegin();
+	const qtractorActionControl::MidiObservers::ConstIterator midi_end
+		= midiObservers.constEnd();
+	for ( ; midi_iter != midi_end; ++midi_iter) {
+		QAction *pAction = midi_iter.key();
+		qtractorActionControl::MidiObserver *pMidiObserver
+			= midi_iter.value();
+		if (!pMidiControl->isMidiObserverMapped(pMidiObserver))
+			continue;
+		const QString& sKey	= '/' + pAction->objectName();
+		QList<QVariant> vlist;
+		vlist.append(qtractorMidiControl::textFromType(pMidiObserver->type()));
+		vlist.append(pMidiObserver->channel());
+		vlist.append(pMidiObserver->param());
+		vlist.append(pMidiObserver->isFeedback());
+		vlist.append(pMidiObserver->isInvert());
+		vlist.append(pMidiObserver->isHook());
+		vlist.append(pMidiObserver->isLatch());
+		m_settings.setValue(sKey, vlist);
+	}
+
+	m_settings.endGroup();
+}
+
+
 // end of qtractorOptions.cpp
