@@ -1,7 +1,7 @@
 // qtractorOptionsForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -33,6 +33,8 @@
 #include "qtractorAudioMeter.h"
 #include "qtractorMidiMeter.h"
 
+#include "qtractorPluginSelectForm.h"
+
 #include <QFileDialog>
 #include <QFontDialog>
 #include <QColorDialog>
@@ -177,6 +179,7 @@ qtractorOptionsForm::qtractorOptionsForm (
 
 	// Initialize dirty control state.
 	m_iDirtyCount = 0;
+	m_iDirtyPluginPaths = 0;
 
 	// Try to restore old window positioning.
 	adjustSize();
@@ -197,6 +200,9 @@ qtractorOptionsForm::qtractorOptionsForm (
 	QObject::connect(m_ui.TransportModeComboBox,
 		SIGNAL(activated(int)),
 		SLOT(changed()));
+	QObject::connect(m_ui.TimebaseCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(changed()));
 	QObject::connect(m_ui.AudioAutoTimeStretchCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(changed()));
@@ -299,6 +305,9 @@ qtractorOptionsForm::qtractorOptionsForm (
 	QObject::connect(m_ui.ConfirmRemoveCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(changed()));
+	QObject::connect(m_ui.ConfirmArchiveCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(changed()));
 	QObject::connect(m_ui.StdoutCaptureCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(changed()));
@@ -409,7 +418,7 @@ qtractorOptionsForm::qtractorOptionsForm (
 		SLOT(moveDownPluginPath()));
 	QObject::connect(m_ui.Lv2PresetDirComboBox,
 		SIGNAL(editTextChanged(const QString&)),
-		SLOT(changed()));
+		SLOT(pluginPathsChanged()));
 	QObject::connect(m_ui.Lv2PresetDirToolButton,
 		SIGNAL(clicked()),
 		SLOT(chooseLv2PresetDir()));
@@ -424,10 +433,10 @@ qtractorOptionsForm::qtractorOptionsForm (
 		SLOT(changed()));
 	QObject::connect(m_ui.DummyVstScanCheckBox,
 		SIGNAL(stateChanged(int)),
-		SLOT(changed()));
+		SLOT(pluginPathsChanged()));
 	QObject::connect(m_ui.Lv2DynManifestCheckBox,
 		SIGNAL(stateChanged(int)),
-		SLOT(changed()));
+		SLOT(pluginPathsChanged()));
 	QObject::connect(m_ui.SaveCurve14bitCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(changed()));
@@ -505,6 +514,7 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 	m_ui.AudioCaptureQualitySpinBox->setValue(m_pOptions->iAudioCaptureQuality);
 	m_ui.AudioResampleTypeComboBox->setCurrentIndex(m_pOptions->iAudioResampleType);
 	m_ui.TransportModeComboBox->setCurrentIndex(m_pOptions->iTransportMode);
+	m_ui.TimebaseCheckBox->setChecked(m_pOptions->bTimebase);
 	m_ui.AudioAutoTimeStretchCheckBox->setChecked(m_pOptions->bAudioAutoTimeStretch);
 #ifdef CONFIG_LIBRUBBERBAND
 	m_ui.AudioWsolaTimeStretchCheckBox->setChecked(m_pOptions->bAudioWsolaTimeStretch);
@@ -632,6 +642,7 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 
 	// Other options finally.
 	m_ui.ConfirmRemoveCheckBox->setChecked(m_pOptions->bConfirmRemove);
+	m_ui.ConfirmArchiveCheckBox->setChecked(m_pOptions->bConfirmArchive);
 	m_ui.StdoutCaptureCheckBox->setChecked(m_pOptions->bStdoutCapture);
 	m_ui.CompletePathCheckBox->setChecked(m_pOptions->bCompletePath);
 	m_ui.PeakAutoRemoveCheckBox->setChecked(m_pOptions->bPeakAutoRemove);
@@ -686,6 +697,8 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 
 	// Done. Restart clean.
 	m_iDirtyCount = 0;
+	m_iDirtyPluginPaths = 0;
+
 	stabilizeForm();
 }
 
@@ -713,6 +726,7 @@ void qtractorOptionsForm::accept (void)
 		m_pOptions->iAudioCaptureQuality = m_ui.AudioCaptureQualitySpinBox->value();
 		m_pOptions->iAudioResampleType   = m_ui.AudioResampleTypeComboBox->currentIndex();
 		m_pOptions->iTransportMode       = m_ui.TransportModeComboBox->currentIndex();
+		m_pOptions->bTimebase            = m_ui.TimebaseCheckBox->isChecked();
 		m_pOptions->bAudioAutoTimeStretch = m_ui.AudioAutoTimeStretchCheckBox->isChecked();
 		m_pOptions->bAudioWsolaTimeStretch = m_ui.AudioWsolaTimeStretchCheckBox->isChecked();
 		m_pOptions->bAudioWsolaQuickSeek = m_ui.AudioWsolaQuickSeekCheckBox->isChecked();
@@ -750,6 +764,7 @@ void qtractorOptionsForm::accept (void)
 		m_pOptions->bMidiMetroBus        = m_ui.MidiMetroBusCheckBox->isChecked();
 		// Display options...
 		m_pOptions->bConfirmRemove       = m_ui.ConfirmRemoveCheckBox->isChecked();
+		m_pOptions->bConfirmArchive      = m_ui.ConfirmArchiveCheckBox->isChecked();
 		m_pOptions->bStdoutCapture       = m_ui.StdoutCaptureCheckBox->isChecked();
 		m_pOptions->bCompletePath        = m_ui.CompletePathCheckBox->isChecked();
 		m_pOptions->bPeakAutoRemove      = m_ui.PeakAutoRemoveCheckBox->isChecked();
@@ -812,7 +827,11 @@ void qtractorOptionsForm::accept (void)
 			m_pOptions->sCustomStyleTheme = m_ui.CustomStyleThemeComboBox->currentText();
 		else
 			m_pOptions->sCustomStyleTheme.clear();
-		// Reset dirty flag.
+		// Reset dirty flags.
+		if (m_iDirtyPluginPaths > 0) {
+			qtractorPluginSelectForm::clearPluginPaths();
+			m_iDirtyPluginPaths = 0;
+		}
 		m_iDirtyCount = 0;
 	}
 
@@ -905,13 +924,13 @@ void qtractorOptionsForm::chooseMetroBeatFilename (void)
 void qtractorOptionsForm::updateMetroNoteNames (void)
 {
 	// Save current selection...
-	int iOldBarNote  = m_ui.MetroBarNoteComboBox->currentIndex();
-	int iOldBeatNote = m_ui.MetroBeatNoteComboBox->currentIndex();
+	const int iOldBarNote  = m_ui.MetroBarNoteComboBox->currentIndex();
+	const int iOldBeatNote = m_ui.MetroBeatNoteComboBox->currentIndex();
 
 	// Populate the Metronome notes.
 	m_ui.MetroBarNoteComboBox->clear();
 	m_ui.MetroBeatNoteComboBox->clear();
-	bool bDrums = (m_ui.MetroChannelSpinBox->value() == 10);
+	const bool bDrums = (m_ui.MetroChannelSpinBox->value() == 10);
 	QStringList items;
 	const QString sItem("%1 (%2)");
 	for (int i = 0; i < 128; ++i) {
@@ -1140,7 +1159,7 @@ void qtractorOptionsForm::addPluginPath (void)
 	m_ui.PluginPathListWidget->setCurrentRow(
 		m_ui.PluginPathListWidget->count() - 1);
 
-	int i = m_ui.PluginPathComboBox->findText(sPluginPath);
+	const int i = m_ui.PluginPathComboBox->findText(sPluginPath);
 	if (i >= 0)
 		m_ui.PluginPathComboBox->removeItem(i);
 	m_ui.PluginPathComboBox->insertItem(0, sPluginPath);
@@ -1149,14 +1168,14 @@ void qtractorOptionsForm::addPluginPath (void)
 	m_ui.PluginPathListWidget->setFocus();
 
 	selectPluginPath();
-	changed();
+	pluginPathsChanged();
 }
 
 
 // Select current plugin path.
 void qtractorOptionsForm::selectPluginPath (void)
 {
-	int iPluginPath = m_ui.PluginPathListWidget->currentRow();
+	const int iPluginPath = m_ui.PluginPathListWidget->currentRow();
 
 	m_ui.PluginPathRemoveToolButton->setEnabled(iPluginPath >= 0);
 	m_ui.PluginPathUpToolButton->setEnabled(iPluginPath > 0);
@@ -1168,7 +1187,7 @@ void qtractorOptionsForm::selectPluginPath (void)
 // Remove current plugin path.
 void qtractorOptionsForm::removePluginPath (void)
 {
-	int iPluginPath = m_ui.PluginPathListWidget->currentRow();
+	const int iPluginPath = m_ui.PluginPathListWidget->currentRow();
 	if (iPluginPath < 0)
 		return;
 
@@ -1197,14 +1216,14 @@ void qtractorOptionsForm::removePluginPath (void)
 		delete pItem;
 
 	selectPluginPath();
-	changed();
+	pluginPathsChanged();
 }
 
 
 // Move up plugin path on search order.
 void qtractorOptionsForm::moveUpPluginPath (void)
 {
-	int iPluginPath = m_ui.PluginPathListWidget->currentRow();
+	const int iPluginPath = m_ui.PluginPathListWidget->currentRow();
 	if (iPluginPath < 1)
 		return;
 
@@ -1242,14 +1261,14 @@ void qtractorOptionsForm::moveUpPluginPath (void)
 	}
 
 	selectPluginPath();
-	changed();
+	pluginPathsChanged();
 }
 
 
 // Move down plugin path on search order.
 void qtractorOptionsForm::moveDownPluginPath (void)
 {
-	int iPluginPath = m_ui.PluginPathListWidget->currentRow();
+	const int iPluginPath = m_ui.PluginPathListWidget->currentRow();
 	if (iPluginPath >= m_ui.PluginPathListWidget->count() - 1)
 		return;
 
@@ -1287,6 +1306,14 @@ void qtractorOptionsForm::moveDownPluginPath (void)
 	}
 
 	selectPluginPath();
+	pluginPathsChanged();
+}
+
+
+// Dirty up plugin-paths.
+void qtractorOptionsForm::pluginPathsChanged (void)
+{
+	++m_iDirtyPluginPaths;
 	changed();
 }
 
@@ -1329,7 +1356,7 @@ void qtractorOptionsForm::chooseLv2PresetDir (void)
 		m_ui.Lv2PresetDirComboBox->setFocus();
 	}
 
-	changed();
+	pluginPathsChanged();
 }
 
 
@@ -1441,12 +1468,12 @@ void qtractorOptionsForm::stabilizeForm (void)
 	const qtractorAudioFileFactory::FileFormat *pFormat
 		= qtractorAudioFileFactory::formats().at(iFormat);
 
-	bool bSndFile
+	const bool bSndFile
 		= (pFormat && pFormat->type == qtractorAudioFileFactory::SndFile);
 	m_ui.AudioCaptureFormatTextLabel->setEnabled(bSndFile);
 	m_ui.AudioCaptureFormatComboBox->setEnabled(bSndFile);
 
-	bool bVorbisFile
+	const bool bVorbisFile
 		= (pFormat && pFormat->type == qtractorAudioFileFactory::VorbisFile);
 	m_ui.AudioCaptureQualityTextLabel->setEnabled(bVorbisFile);
 	m_ui.AudioCaptureQualitySpinBox->setEnabled(bVorbisFile);
@@ -1463,7 +1490,7 @@ void qtractorOptionsForm::stabilizeForm (void)
 	m_ui.AudioPlayerAutoConnectCheckBox->setEnabled(
 		m_ui.AudioPlayerBusCheckBox->isChecked());
 
-	bool bAudioMetronome = m_ui.AudioMetronomeCheckBox->isChecked();
+	const bool bAudioMetronome = m_ui.AudioMetronomeCheckBox->isChecked();
 	m_ui.MetroBarFilenameTextLabel->setEnabled(bAudioMetronome);
 	m_ui.MetroBarFilenameComboBox->setEnabled(bAudioMetronome);
 	m_ui.MetroBarFilenameToolButton->setEnabled(bAudioMetronome);
@@ -1479,11 +1506,11 @@ void qtractorOptionsForm::stabilizeForm (void)
 	m_ui.AudioMetroAutoConnectCheckBox->setEnabled(
 		bAudioMetronome && m_ui.AudioMetroBusCheckBox->isChecked());
 
-	bool bMmcMode =(m_ui.MidiMmcModeComboBox->currentIndex() > 0);
+	const bool bMmcMode =(m_ui.MidiMmcModeComboBox->currentIndex() > 0);
 	m_ui.MidiMmcDeviceTextLabel->setEnabled(bMmcMode);
 	m_ui.MidiMmcDeviceComboBox->setEnabled(bMmcMode);
 
-	bool bMidiMetronome = m_ui.MidiMetronomeCheckBox->isChecked();
+	const bool bMidiMetronome = m_ui.MidiMetronomeCheckBox->isChecked();
 	m_ui.MetroChannelTextLabel->setEnabled(bMidiMetronome);
 	m_ui.MetroChannelSpinBox->setEnabled(bMidiMetronome);
 	m_ui.MetroBarNoteTextLabel->setEnabled(bMidiMetronome);
@@ -1500,7 +1527,7 @@ void qtractorOptionsForm::stabilizeForm (void)
 	m_ui.MetroBeatDurationSpinBox->setEnabled(bMidiMetronome);
 	m_ui.MidiMetroBusCheckBox->setEnabled(bMidiMetronome);
 
-	bool bMessagesLog = m_ui.MessagesLogCheckBox->isChecked();
+	const bool bMessagesLog = m_ui.MessagesLogCheckBox->isChecked();
 	m_ui.MessagesLogPathComboBox->setEnabled(bMessagesLog);
 	m_ui.MessagesLogPathToolButton->setEnabled(bMessagesLog);
 	if (bMessagesLog && bValid) {
@@ -1508,7 +1535,7 @@ void qtractorOptionsForm::stabilizeForm (void)
 		bValid = !sPath.isEmpty();
 	}
 
-	bool bSessionTemplate = m_ui.SessionTemplateCheckBox->isChecked();
+	const bool bSessionTemplate = m_ui.SessionTemplateCheckBox->isChecked();
 	m_ui.SessionTemplatePathComboBox->setEnabled(bSessionTemplate);
 	m_ui.SessionTemplatePathToolButton->setEnabled(bSessionTemplate);
 	if (bSessionTemplate && bValid) {
