@@ -29,6 +29,7 @@
 #include "qtractorMidiBuffer.h"
 
 #include "qtractorOptions.h"
+#include "qtractorMainForm.h"
 
 #include "qtractorSession.h"
 #include "qtractorDocument.h"
@@ -881,19 +882,17 @@ void qtractorPlugin::clearItems (void)
 }
 
 
-// Special plugin form accessors.
-bool qtractorPlugin::isFormVisible (void) const
-{
-	return (m_pForm ? m_pForm->isVisible() : false);
-}
-
-qtractorPluginForm *qtractorPlugin::form (void)
+// Special plugin form methods.
+void qtractorPlugin::openForm ( QWidget *pParent )
 {
 	// Take the change and create the form if it doesn't current exist.
-	if (m_pForm == NULL) {
+	const bool bCreate = (m_pForm == NULL);
+
+	if (bCreate) {
 		// Build up the plugin form...
-		// What style do we create tool childs?
-		QWidget *pParent = NULL;
+		if (pParent == NULL)
+			pParent = qtractorMainForm::getInstance();
+	// What style do we create tool childs?
 		Qt::WindowFlags wflags = Qt::Window
 			| Qt::CustomizeWindowHint
 			| Qt::WindowTitleHint
@@ -902,7 +901,6 @@ qtractorPluginForm *qtractorPlugin::form (void)
 			| Qt::WindowCloseButtonHint;
 		qtractorOptions *pOptions = qtractorOptions::getInstance();
 		if (pOptions && pOptions->bKeepToolsOnTop) {
-		//	pParent = qtractorMainForm::getInstance();
 			wflags |= Qt::Tool;
 		}
 		// Do it...
@@ -910,7 +908,90 @@ qtractorPluginForm *qtractorPlugin::form (void)
 		m_pForm->setPlugin(this);
 	}
 
-	return m_pForm;
+	// Activate form...
+	if (!m_pForm->isVisible()) {
+		m_pForm->toggleEditor(isEditorVisible());
+		m_pForm->show();
+	}
+
+	m_pForm->raise();
+	m_pForm->activateWindow();
+
+	if (bCreate)
+		moveWidgetPos(m_pForm, m_posForm);
+}
+
+
+void qtractorPlugin::closeForm (void)
+{
+	if (m_pForm && m_pForm->isVisible())
+		m_pForm->hide();
+}
+
+
+bool qtractorPlugin::isFormVisible (void) const
+{
+	return (m_pForm && m_pForm->isVisible());
+}
+
+
+void qtractorPlugin::toggleFormEditor ( bool bOn )
+{
+	if (m_pForm && m_pForm->isVisible())
+		m_pForm->toggleEditor(bOn);
+}
+
+
+void qtractorPlugin::updateFormParamValue ( unsigned long iIndex )
+{
+	if (m_pForm && m_pForm->isVisible())
+		m_pForm->updateParamValue(iIndex);
+}
+
+
+void qtractorPlugin::updateFormAudioBusName (void)
+{
+	if (m_pForm && m_pForm->isVisible())
+		m_pForm->updateAudioBusName();
+}
+
+
+void qtractorPlugin::refreshForm (void)
+{
+	if (m_pForm && m_pForm->isVisible())
+		m_pForm->refresh();
+}
+
+
+void qtractorPlugin::freezeFormPos (void)
+{
+	if (m_pForm && m_pForm->isVisible())
+		m_posForm = m_pForm->pos();
+}
+
+
+// Move widget to alleged parent center or else...
+void qtractorPlugin::moveWidgetPos (
+	QWidget *pWidget, const QPoint& wpos ) const
+{
+	QPoint pos(wpos);
+
+	if (pos.isNull() || pos.x() < 0 || pos.y() < 0) {
+		QWidget *pParent = pWidget->parentWidget();
+		if (pParent == NULL)
+			pParent = qtractorMainForm::getInstance();
+		if (pParent && pParent->isVisible()) {
+			const QSize& delta = pParent->size() - pWidget->size();
+			if (delta.isValid()) {
+				pos = pParent->pos() + QPoint(
+					delta.width()  >> 1,
+					delta.height() >> 1);
+			}
+		}
+	}
+
+	if (!pos.isNull() && pos.x() >= 0 && pos.y() >= 0)
+		pWidget->move(pos);
 }
 
 
@@ -1148,9 +1229,15 @@ bool qtractorPlugin::isDirectAccessParam (void) const
 // Write the value to the display item.
 void qtractorPlugin::updateDirectAccessParam (void)
 {
+#if QT_VERSION >= 0x050000
+	QListIterator<qtractorPluginListView *> iter(m_pList->views());
+	while (iter.hasNext())
+		iter.next()->viewport()->update();
+#else
 	QListIterator<qtractorPluginListItem *> iter(m_items);
 	while (iter.hasNext())
 		iter.next()->updateActivated();
+#endif
 }
 
 
@@ -2221,8 +2308,7 @@ bool qtractorPluginList::saveElement ( qtractorDocument *pDocument,
 			pPlugin; pPlugin = pPlugin->next()) {
 
 		// Freeze form position, if currently visible...
-		if (pPlugin->isFormVisible())
-			pPlugin->setFormPos((pPlugin->form())->pos());
+		pPlugin->freezeFormPos();
 
 		// Do freeze plugin state...
 		pPlugin->freezeConfigs();
@@ -2282,13 +2368,13 @@ bool qtractorPluginList::saveElement ( qtractorDocument *pDocument,
 		}
 		// Save editor position...
 		const QPoint& posEditor = pPlugin->editorPos();
-		if (!posEditor.isNull()) {
+		if (posEditor.x() >= 0 && posEditor.y() >= 0) {
 			pDocument->saveTextElement("editor-pos",
 				QString::number(posEditor.x()) + ',' +
 				QString::number(posEditor.y()), &ePlugin);
 		}
 		const QPoint& posForm = pPlugin->formPos();
-		if (!posForm.isNull()) {
+		if (posForm.x() >= 0 && posForm.y() >= 0) {
 			pDocument->saveTextElement("form-pos",
 				QString::number(posForm.x()) + ',' +
 				QString::number(posForm.y()), &ePlugin);
