@@ -28,6 +28,7 @@
 
 #include <QStringList>
 #include <QLibrary>
+#include <QPoint>
 #include <QSize>
 
 #include <QHash>
@@ -551,6 +552,9 @@ public:
 	const QPoint& editorPos() const
 		{ return m_posEditor; }
 
+	// Move widget to alleged parent center or else...
+	void moveWidgetPos(QWidget *pWidget, const QPoint& wpos) const;
+
 	// An accessible list of observers.
 	const QList<qtractorPluginListItem *>& items() const
 		{ return m_items; }
@@ -560,9 +564,18 @@ public:
 	void removeItem(qtractorPluginListItem *pItem);
 	void clearItems();
 
-	// Special plugin form accessors.
+	// Special plugin form methods.
+	void openForm(QWidget *pParent = NULL);
+	void closeForm();
+
 	bool isFormVisible() const;
-	qtractorPluginForm *form();
+
+	void toggleFormEditor(bool bOn);
+	void updateFormParamValue(unsigned long iIndex);
+	void updateFormAudioBusName();
+	void refreshForm();
+
+	void freezeFormPos();
 
 	void setFormPos(const QPoint& pos)
 		{ m_posForm = pos; }
@@ -756,6 +769,7 @@ private:
 
 	// The plugin form reference.
 	qtractorPluginForm *m_pForm;
+
 	QString m_sPreset;
 	QPoint  m_posForm;
 
