@@ -52,6 +52,7 @@
 
 #include <QMenu>
 #include <QKeyEvent>
+#include <QHideEvent>
 
 #include "math.h"
 
@@ -166,8 +167,7 @@ void qtractorPluginForm::setPlugin ( qtractorPlugin *pPlugin )
 	const int MaxColumnsPerPage = (bVstPlugin ?  2 : 3);
 	const int MaxParamsPerPage  = MaxRowsPerPage * MaxColumnsPerPage;
 
-	const qtractorPlugin::Params& params
-		= m_pPlugin->params();
+	const qtractorPlugin::Params& params = m_pPlugin->params();
 	const int iParams = params.count();
 
 	int iParamsPerPage = iParams;
@@ -300,39 +300,6 @@ void qtractorPluginForm::setPlugin ( qtractorPlugin *pPlugin )
 	updateActivated();
 	refresh();
 	stabilize();
-
-	const QPoint& pos = m_pPlugin->formPos();
-	if (!pos.isNull())
-		move(pos);
-
-	show();
-}
-
-
-void qtractorPluginForm::activateForm (void)
-{
-	if (!isVisible()) {
-		if (m_pPlugin) toggleEditor(m_pPlugin->isEditorVisible());
-		show();
-	}
-
-	raise();
-	activateWindow();
-}
-
-
-// Editor widget methods.
-void qtractorPluginForm::toggleEditor ( bool bOn )
-{
-	if (m_pPlugin == NULL)
-		return;
-
-	if (m_iUpdate > 0)
-		return;
-
-	++m_iUpdate;
-	m_ui.EditToolButton->setChecked(bOn);
-	--m_iUpdate;
 }
 
 
@@ -382,6 +349,26 @@ void qtractorPluginForm::updateActivated (void)
 }
 
 
+// Update port widget state.
+void qtractorPluginForm::updateParamValue ( unsigned long /*iIndex*/ )
+{
+#ifdef CONFIG_DEBUG_0
+	qDebug("qtractorPluginForm[%p]::updateParamValue(%lu)", this, iIndex);
+#endif
+
+#if 0
+	qtractorPluginParamWidget *pParamWidget
+		= m_paramWidgets.value(iIndex, NULL);
+	if (pParamWidget)
+		pParamWidget->refresh();
+#endif
+
+	// Sure is dirty...
+	++m_iDirtyCount;
+	stabilize();
+}
+
+
 // Update specific aux-send audio bus settings.
 void qtractorPluginForm::updateAudioBusName (void)
 {
@@ -425,23 +412,18 @@ void qtractorPluginForm::updateAudioBusName (void)
 }
 
 
-// Update port widget state.
-void qtractorPluginForm::changeParamValue ( unsigned long /*iIndex*/ )
+// Editor widget methods.
+void qtractorPluginForm::toggleEditor ( bool bOn )
 {
-#ifdef CONFIG_DEBUG_0
-	qDebug("qtractorPluginForm[%p]::changeParamValue(%lu)", this, iIndex);
-#endif
+	if (m_pPlugin == NULL)
+		return;
 
-#if 0
-	qtractorPluginParamWidget *pParamWidget
-		= m_paramWidgets.value(iIndex, NULL);
-	if (pParamWidget)
-		pParamWidget->refresh();
-#endif
+	if (m_iUpdate > 0)
+		return;
 
-	// Sure is dirty...
-	++m_iDirtyCount;
-	stabilize();
+	++m_iUpdate;
+	m_ui.EditToolButton->setChecked(bOn);
+	--m_iUpdate;
 }
 
 
@@ -685,7 +667,7 @@ void qtractorPluginForm::editSlot ( bool bOn )
 	++m_iUpdate;
 
 	if (bOn)
-		m_pPlugin->openEditor(this);
+		m_pPlugin->openEditor(NULL);
 	else
 		m_pPlugin->closeEditor();
 
@@ -946,17 +928,18 @@ void qtractorPluginForm::keyPressEvent ( QKeyEvent *pKeyEvent )
 }
 
 
-// Form close event (save visible position).
-void qtractorPluginForm::closeEvent ( QCloseEvent *pCloseEvent )
+// Form hide event (save visible position).
+void qtractorPluginForm::hideEvent ( QHideEvent *pHideEvent )
 {
 #ifdef CONFIG_DEBUG_0
-	qDebug("qtractorPluginForm::closeEvent()");
+	qDebug("qtractorPluginForm[%p]::hideEvent()", this);
 #endif
 
+	// Save current form position...
 	if (m_pPlugin)
 		m_pPlugin->setFormPos(QWidget::pos());
 
-	QWidget::closeEvent(pCloseEvent);
+	QWidget::hideEvent(pHideEvent);
 }
 
 
@@ -1069,7 +1052,7 @@ private:
 // Constructor.
 qtractorPluginParamWidget::qtractorPluginParamWidget (
 	qtractorPluginParam *pParam, QWidget *pParent )
-	: QFrame(pParent), m_pParam(pParam)
+	: QWidget(pParent), m_pParam(pParam)
 {
 	m_pSlider   = NULL;
 	m_pSpinBox  = NULL;
@@ -1173,10 +1156,8 @@ qtractorPluginParamWidget::qtractorPluginParamWidget (
 			SLOT(updateValue(float)));
 	}
 
-	QFrame::setLayout(pGridLayout);
-//	QFrame::setFrameShape(QFrame::StyledPanel);
-//	QFrame::setFrameShadow(QFrame::Raised);
-	QFrame::setToolTip(m_pParam->name());
+	QWidget::setLayout(pGridLayout);
+	QWidget::setToolTip(m_pParam->name());
 }
 
 
