@@ -24,7 +24,6 @@
 
 #include "ui_qtractorPluginForm.h"
 
-#include <QFrame>
 #include <QHash>
 
 
@@ -41,7 +40,6 @@ class qtractorObserverSpinBox;
 
 class qtractorPluginParamDisplay;
 
-
 //----------------------------------------------------------------------------
 // qtractorPluginForm -- UI wrapper form.
 
@@ -64,18 +62,14 @@ public:
 	QString preset() const;
 
 	void updateActivated();
-
-	void changeParamValue(unsigned long iIndex);
-
+	void updateParamValue(unsigned long iIndex);
 	void updateAudioBusName();
 
-	void activateForm();
+	void toggleEditor(bool bOn);
 
 	void refresh();
 	void clear();
 
-	void toggleEditor(bool bOn);
-
 protected slots:
 
 	void changePresetSlot(const QString& sPreset);
@@ -111,8 +105,8 @@ protected:
 	// Keyboard event handler.
 	void keyPressEvent(QKeyEvent *);
 
-	// Form close event (save visible position).
-	void closeEvent(QCloseEvent *pCloseEvent);
+	// Form show/hide events (restore/save position).
+	void hideEvent(QHideEvent *);
 
 private:
 
@@ -136,7 +130,7 @@ private:
 // qtractorPluginParamWidget -- Plugin port widget.
 //
 
-class qtractorPluginParamWidget : public QFrame
+class qtractorPluginParamWidget : public QWidget
 {
 	Q_OBJECT
 
