@@ -1,7 +1,7 @@
 // qtractorPluginSelectForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -51,6 +51,9 @@ public:
 	qtractorPluginType::Hint pluginTypeHint(int iPlugin) const;
 	bool isPluginActivated() const;
 
+	// External accesss.
+	static void clearPluginPaths();
+
 protected slots:
 
 	void typeHintChanged(int iTypeHint);
