@@ -1414,7 +1414,10 @@ unsigned long qtractorSession::frameTimeEx (void) const
 // Sanitize a given name.
 QString qtractorSession::sanitize ( const QString& s )
 {
-	return s.simplified().replace(QRegExp("[\\s|\\.|\\-|/]+"), "_");
+//	return s.simplified().replace(QRegExp("[\\s|\\.|\\-|/]+"), "_");
+	const QChar space(' ');
+	const QRegExp regex("[^\\w]+");
+	return QString(s).replace(regex, space).simplified().replace(space, "_");
 }
 
 
@@ -1482,12 +1485,6 @@ int qtractorSession::loopRecordingMode (void) const
 	return m_iLoopRecordingMode;
 }
 
-// Loop-recording/take state.
-bool qtractorSession::isLoopRecording (void) const
-{
-	return isLooping() && (m_iLoopRecordingMode > 0);
-}
-
 
 // Immediate track record-arming.
 void qtractorSession::trackRecord (
