@@ -1,7 +1,7 @@
 // qtractorSessionForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -61,8 +61,18 @@ qtractorSessionForm::qtractorSessionForm (
 		new QIntValidator(m_ui.SampleRateComboBox));
 
 	// Fill-up snap-per-beat items...
+	const QIcon snapIcon(":/images/itemBeat.png");
+	const QStringList& snapItems = qtractorTimeScale::snapItems(0);
+	QStringListIterator snapIter(snapItems);
 	m_ui.SnapPerBeatComboBox->clear();
-	m_ui.SnapPerBeatComboBox->insertItems(0, qtractorTimeScale::snapItems());
+	m_ui.SnapPerBeatComboBox->setIconSize(QSize(8, 16));
+//	snapIter.toFront();
+	if (snapIter.hasNext())
+		m_ui.SnapPerBeatComboBox->addItem(
+			QIcon(":/images/itemNone.png"), snapIter.next());
+	while (snapIter.hasNext())
+		m_ui.SnapPerBeatComboBox->addItem(snapIcon, snapIter.next());
+//	m_ui.SnapPerBeatComboBox->insertItems(0, snapItems);
 
 	// Initialize dirty control state.
 	m_iDirtyCount = 0;
@@ -271,9 +281,16 @@ void qtractorSessionForm::stabilizeForm (void)
 // Browse for session directory.
 void qtractorSessionForm::browseSessionDir (void)
 {
-	const QString& sTitle = tr("Session Directory") + " - " QTRACTOR_TITLE; 
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions == NULL)
+		return;
+
+	const QString& sTitle = tr("Session Directory") + " - " QTRACTOR_TITLE;
 #if 1// QT_VERSION < 0x040400
-    QString sSessionDir = QFileDialog::getExistingDirectory(this,                                  // Parent.
+	QFileDialog::Options options = QFileDialog::ShowDirsOnly;
+	if (pOptions->bDontUseNativeDialogs)
+		options |= QFileDialog::DontUseNativeDialog;
+	QString sSessionDir = QFileDialog::getExistingDirectory(this,                                  // Parent.
 		sTitle, m_ui.SessionDirComboBox->currentText());
 #else
 	// Construct open-directory dialog...
@@ -283,12 +300,11 @@ void qtractorSessionForm::browseSessionDir (void)
 	fileDialog.setAcceptMode(QFileDialog::AcceptOpen);
 	fileDialog.setFileMode(QFileDialog::DirectoryOnly);
 	// Stuff sidebar...
-	qtractorOptions *pOptions = qtractorOptions::getInstance();
-	if (pOptions) {
-		QList<QUrl> urls(fileDialog.sidebarUrls());
-		urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
-		fileDialog.setSidebarUrls(urls);
-	}
+	QList<QUrl> urls(fileDialog.sidebarUrls());
+	urls.append(QUrl::fromLocalFile(pOptions->sSessionDir));
+	fileDialog.setSidebarUrls(urls);
+	if (pOptions->bDontUseNativeDialogs)
+		fileDialog.setOptions(QFileDialog::DontUseNativeDialog);
 	// Show dialog...
 	if (!fileDialog.exec())
 		return;
