@@ -1,7 +1,7 @@
 // qtractorShortcutForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,9 +22,15 @@
 #include "qtractorAbout.h"
 #include "qtractorShortcutForm.h"
 
+#include "qtractorActionControl.h"
+
+#include "qtractorMidiControlObserverForm.h"
+
 #include "qtractorOptions.h"
 
 #include <QAction>
+#include <QMenu>
+
 #include <QMessageBox>
 #include <QPushButton>
 #include <QHeaderView>
@@ -35,33 +41,16 @@
 #include <QKeyEvent>
 
 
-//-------------------------------------------------------------------------
-// qtractorShortcutTableItem
-
-class qtractorShortcutTableItem : public QTableWidgetItem
-{
-public:
-
-	// Constructors.
-	qtractorShortcutTableItem(const QIcon& icon, const QString& sText)
-		: QTableWidgetItem(icon, sText)
-		{ setFlags(flags() & ~Qt::ItemIsEditable); }
-	qtractorShortcutTableItem(const QString& sText)
-		: QTableWidgetItem(sText)
-		{ setFlags(flags() & ~Qt::ItemIsEditable); }
-	qtractorShortcutTableItem(const QKeySequence& shortcut)
-		: QTableWidgetItem(shortcut.toString()) {}
-};
-
-
 //-------------------------------------------------------------------------
 // qtractorShortcutTableItemEdit
 
 // Shortcut key to text event translation.
 void qtractorShortcutTableItemEdit::keyPressEvent ( QKeyEvent *pKeyEvent )
 {
+	const Qt::KeyboardModifiers modifiers
+		= pKeyEvent->modifiers();
+
 	int iKey = pKeyEvent->key();
-	Qt::KeyboardModifiers modifiers = pKeyEvent->modifiers();
 
 	if (modifiers == Qt::NoModifier) {
 		switch (iKey) {
@@ -152,7 +141,7 @@ void qtractorShortcutTableItemEditor::clear (void)
 // Shortcut text finish notification.
 void qtractorShortcutTableItemEditor::finish (void)
 {
-	bool bBlockSignals = m_pItemEdit->blockSignals(true);
+	const bool bBlockSignals = m_pItemEdit->blockSignals(true);
 	emit editingFinished();
 	m_index = QModelIndex();
 	m_sDefaultText.clear();
@@ -163,7 +152,7 @@ void qtractorShortcutTableItemEditor::finish (void)
 // Shortcut text cancel notification.
 void qtractorShortcutTableItemEditor::cancel (void)
 {
-	bool bBlockSignals = m_pItemEdit->blockSignals(true);
+	const bool bBlockSignals = m_pItemEdit->blockSignals(true);
 	m_index = QModelIndex();
 	m_sDefaultText.clear();
 	emit editingFinished();
@@ -176,7 +165,8 @@ void qtractorShortcutTableItemEditor::cancel (void)
 
 qtractorShortcutTableItemDelegate::qtractorShortcutTableItemDelegate (
 	qtractorShortcutForm *pShortcutForm )
-	: QItemDelegate(pShortcutForm->tableWidget()), m_pShortcutForm(pShortcutForm)
+	: QItemDelegate(pShortcutForm->tableWidget()),
+		m_pShortcutForm(pShortcutForm)
 {
 }
 
@@ -187,8 +177,6 @@ void qtractorShortcutTableItemDelegate::paint ( QPainter *pPainter,
 {
 	// Special treatment for action icon+text...
 	if (index.column() == 0) {
-		QTableWidget *pTableWidget = m_pShortcutForm->tableWidget();
-		QTableWidgetItem *pItem	= pTableWidget->item(index.row(), 0);
 		pPainter->save();
 		if (option.state & QStyle::State_Selected) {
 			const QPalette& pal = option.palette;
@@ -197,15 +185,17 @@ void qtractorShortcutTableItemDelegate::paint ( QPainter *pPainter,
 		}
 		// Draw the icon...
 		QRect rect = option.rect;
-		const QSize& iconSize = pTableWidget->iconSize();
+		const QSize iconSize(16, 16);
+		const QIcon& icon
+			= index.model()->data(index, Qt::DecorationRole).value<QIcon>();
 		pPainter->drawPixmap(1,
 			rect.top() + ((rect.height() - iconSize.height()) >> 1),
-			pItem->icon().pixmap(iconSize));
+			icon.pixmap(iconSize));
 		// Draw the text...
 		rect.setLeft(iconSize.width() + 2);
 		pPainter->drawText(rect,
 			Qt::TextShowMnemonic | Qt::AlignLeft | Qt::AlignVCenter,
-			pItem->text());
+			index.model()->data(index, Qt::DisplayRole).toString());
 		pPainter->restore();
 	} else {
 		// Others do as default...
@@ -217,6 +207,7 @@ void qtractorShortcutTableItemDelegate::paint ( QPainter *pPainter,
 QWidget *qtractorShortcutTableItemDelegate::createEditor ( QWidget *pParent,
 	const QStyleOptionViewItem& /*option*/, const QModelIndex& index ) const
 {
+	// Keyboard shortcut.
 	qtractorShortcutTableItemEditor *pItemEditor
 		= new qtractorShortcutTableItemEditor(pParent);
 	pItemEditor->setIndex(index);
@@ -260,9 +251,17 @@ void qtractorShortcutTableItemDelegate::commitEditor (void)
 }
 
 
+QSize qtractorShortcutTableItemDelegate::sizeHint (
+	const QStyleOptionViewItem& option, const QModelIndex& index ) const
+{
+	return QItemDelegate::sizeHint(option, index) + QSize(4, 4);
+}
+
+
 //-------------------------------------------------------------------------
 // qtractorShortcutForm
 
+// Constructor.
 qtractorShortcutForm::qtractorShortcutForm (
 	const QList<QAction *>& actions, QWidget *pParent ) : QDialog(pParent)
 {
@@ -272,61 +271,69 @@ qtractorShortcutForm::qtractorShortcutForm (
 	// Window modality (let plugin/tool windows rave around).
 	QDialog::setWindowModality(Qt::ApplicationModal);
 
-	m_iDirtyCount = 0;
+	m_pActionControl = NULL;
 
-//	m_ui.qtractorShortcutTable = new QTableWidget(0, 3, this);
-	m_ui.ShortcutTable->setIconSize(QSize(16, 16));
+	m_iDirtyActionShortcuts = 0;
+	m_iDirtyActionControl = 0;
+
+	m_pActionControlItem = NULL;
+
+//	m_ui.ShortcutTable->setIconSize(QSize(16, 16));
 	m_ui.ShortcutTable->setItemDelegate(
 		new qtractorShortcutTableItemDelegate(this));
-//	m_ui.ShortcutTable->setSelectionMode(QAbstractItemView::SingleSelection);
-//	m_ui.ShortcutTable->setSelectionBehavior(QAbstractItemView::SelectRows);
-//	m_ui.ShortcutTable->setAlternatingRowColors(true);
-//	m_ui.ShortcutTable->setSortingEnabled(true);
 
-//	m_ui.ShortcutTable->setHorizontalHeaderLabels(
-//		QStringList() << tr("Item") << tr("Description") << tr("Shortcut"));
-	m_ui.ShortcutTable->horizontalHeader()->setStretchLastSection(true);
-	m_ui.ShortcutTable->horizontalHeader()->setDefaultAlignment(Qt::AlignLeft);
-	m_ui.ShortcutTable->horizontalHeader()->resizeSection(0, 120);
-	m_ui.ShortcutTable->horizontalHeader()->resizeSection(1, 260);
+	QHeaderView *pHeaderView = m_ui.ShortcutTable->header();
+	pHeaderView->setStretchLastSection(true);
+	pHeaderView->setDefaultAlignment(Qt::AlignLeft);
+	pHeaderView->resizeSection(0, 180);
+	pHeaderView->resizeSection(1, 320);
+//	pHeaderView->hideSection(3);
 
-	int iRowHeight = m_ui.ShortcutTable->fontMetrics().height() + 4;
-	m_ui.ShortcutTable->verticalHeader()->setDefaultSectionSize(iRowHeight);
-	m_ui.ShortcutTable->verticalHeader()->hide();
-
-	int iRow = 0;
+	QList<QTreeWidgetItem *> items;
 	QListIterator<QAction *> iter(actions);
 	while (iter.hasNext()) {
 		QAction *pAction = iter.next();
 		if (pAction->objectName().isEmpty())
 			continue;
-		m_ui.ShortcutTable->insertRow(iRow);
-		m_ui.ShortcutTable->setItem(iRow, 0,
-			new qtractorShortcutTableItem(pAction->icon(), pAction->text()));
-		m_ui.ShortcutTable->setItem(iRow, 1,
-			new qtractorShortcutTableItem(pAction->statusTip()));
+		QTreeWidgetItem *pItem = new QTreeWidgetItem(m_ui.ShortcutTable);
+		const QString& sActionText
+			= qtractorActionControl::menuActionText(pAction, pAction->text());
+		pItem->setIcon(0, pAction->icon());
+		pItem->setText(0, sActionText);
+		pItem->setText(1, pAction->statusTip());
 		const QKeySequence& shortcut = pAction->shortcut();
 		const QString& sShortcutText = shortcut.toString();
-		m_ui.ShortcutTable->setItem(iRow, 2,
-			new qtractorShortcutTableItem(shortcut));
-		m_actions.insert(pAction, iRow);
+		pItem->setText(2, sShortcutText);
+	//	pItem->setText(3, actionControlText(pAction));
+		pItem->setFlags(
+			Qt::ItemIsEnabled | Qt::ItemIsEditable | Qt::ItemIsSelectable);
+		m_actions.insert(pItem, pAction);
 		if (!sShortcutText.isEmpty())
-			m_shortcuts.insert(sShortcutText, iRow);
-		++iRow;
+			m_shortcuts.insert(sShortcutText, pItem);
+		items.append(pItem);
 	}
+	m_ui.ShortcutTable->addTopLevelItems(items);
+	m_ui.ShortcutTable->expandAll();
+
+	// Custom context menu...
+	m_ui.ShortcutTable->setContextMenuPolicy(Qt::CustomContextMenu);
 
 	// Restore last seen form position and extents...
 	qtractorOptions *pOptions = qtractorOptions::getInstance();
 	if (pOptions)
 		pOptions->loadWidgetGeometry(this, true);
-	
-	QObject::connect(m_ui.ShortcutTable,
-		SIGNAL(itemActivated(QTableWidgetItem *)),
-		SLOT(actionActivated(QTableWidgetItem *)));
 
 	QObject::connect(m_ui.ShortcutTable,
-		SIGNAL(itemChanged(QTableWidgetItem *)),
-		SLOT(actionChanged(QTableWidgetItem *)));
+		SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)),
+		SLOT(actionShortcutActivated(QTreeWidgetItem *, int)));
+
+	QObject::connect(m_ui.ShortcutTable,
+		SIGNAL(itemChanged(QTreeWidgetItem *, int)),
+		SLOT(actionShortcutChanged(QTreeWidgetItem *, int)));
+
+	QObject::connect(m_ui.ShortcutTable,
+		SIGNAL(customContextMenuRequested(const QPoint&)),
+		SLOT(actionControlMenuRequested(const QPoint&)));
 
 	QObject::connect(m_ui.DialogButtonBox,
 		SIGNAL(accepted()),
@@ -334,6 +341,8 @@ qtractorShortcutForm::qtractorShortcutForm (
 	QObject::connect(m_ui.DialogButtonBox,
 		SIGNAL(rejected()),
 		SLOT(reject()));
+
+	stabilizeForm();
 }
 
 
@@ -346,12 +355,50 @@ qtractorShortcutForm::~qtractorShortcutForm (void)
 }
 
 
-QTableWidget *qtractorShortcutForm::tableWidget (void) const
+// Action shortcut/control table widget accessor.
+QTreeWidget *qtractorShortcutForm::tableWidget (void) const
 {
 	return m_ui.ShortcutTable;
 }
 
 
+// MIDI Controller manager accessor.
+void qtractorShortcutForm::setActionControl ( qtractorActionControl *pActionControl )
+{
+	m_pActionControl = pActionControl;
+
+	QHeaderView *pHeaderView = m_ui.ShortcutTable->header();
+	if (m_pActionControl) {
+		QHash<QTreeWidgetItem *, QAction *>::ConstIterator iter
+			= m_actions.constBegin();
+		const QHash<QTreeWidgetItem *, QAction *>::ConstIterator& iter_end
+			= m_actions.constEnd();
+		for ( ; iter != iter_end; ++iter)
+			iter.key()->setText(3, actionControlText(iter.value()));
+		pHeaderView->showSection(3);
+	} else {
+		pHeaderView->hideSection(3);
+	}
+}
+
+qtractorActionControl *qtractorShortcutForm::actionControl (void) const
+{
+	return m_pActionControl;
+}
+
+
+// Action shortcut/control dirty-flag accessors.
+bool qtractorShortcutForm::isDirtyActionShortcuts (void) const
+{
+	return (m_iDirtyActionShortcuts > 0);
+}
+
+bool qtractorShortcutForm::isDirtyActionControl (void) const
+{
+	return (m_iDirtyActionControl > 0);
+}
+
+
 // Shortcut action finder & settler.
 bool qtractorShortcutForm::commitEditor (
 	qtractorShortcutTableItemEditor *pItemEditor )
@@ -376,7 +423,9 @@ bool qtractorShortcutForm::commitEditor (
 			pItemEditor->clear();
 			return false;
 		}
-		m_shortcuts.insert(sShortcutText, index.row());
+		QTreeWidgetItem *pItem
+			= m_ui.ShortcutTable->topLevelItem(index.row());
+		if (pItem) m_shortcuts.insert(sShortcutText, pItem);
 	}
 
 	if (!sDefaultText.isEmpty())
@@ -386,31 +435,46 @@ bool qtractorShortcutForm::commitEditor (
 }
 
 
-void qtractorShortcutForm::actionActivated ( QTableWidgetItem *pItem )
+void qtractorShortcutForm::actionShortcutActivated (
+	QTreeWidgetItem *pItem, int iColumn )
 {
-	m_ui.ShortcutTable->editItem(m_ui.ShortcutTable->item(pItem->row(), 2));
+	switch (iColumn) {
+	case 3:
+		// MIDI Controller...
+		actionControlActivated();
+		break;
+	case 2:
+	default:
+		// Keyboard shortcut...
+		m_ui.ShortcutTable->editItem(pItem, 2);
+		break;
+	}
 }
 
 
-void qtractorShortcutForm::actionChanged ( QTableWidgetItem *pItem )
+void qtractorShortcutForm::actionShortcutChanged (
+	QTreeWidgetItem *pItem, int iColumn )
 {
-	const QString& sShortcutText
-		= QKeySequence(pItem->text().trimmed()).toString();
-	pItem->setText(sShortcutText);
-	++m_iDirtyCount;
+	if (iColumn == 2) {
+		const QString& sShortcutText
+			= QKeySequence(pItem->text(2).trimmed()).toString();
+		pItem->setText(2, sShortcutText);
+		++m_iDirtyActionShortcuts;
+	}
+
+	stabilizeForm();
 }
 
 
 void qtractorShortcutForm::accept (void)
 {
-	if (m_iDirtyCount > 0) {
-		QHash<QAction *, int>::ConstIterator iter = m_actions.constBegin();
-		const QHash<QAction *, int>::ConstIterator& iter_end = m_actions.constEnd();
-		for ( ; iter != iter_end; ++iter) {
-			const QString& sShortcutText
-				= m_ui.ShortcutTable->item(iter.value(), 2)->text();
-			iter.key()->setShortcut(QKeySequence(sShortcutText));
-		}
+	if (m_iDirtyActionShortcuts > 0) {
+		QHash<QTreeWidgetItem *, QAction *>::ConstIterator iter
+			= m_actions.constBegin();
+		const QHash<QTreeWidgetItem *, QAction *>::ConstIterator& iter_end
+			= m_actions.constEnd();
+		for ( ; iter != iter_end; ++iter)
+			iter.value()->setShortcut(QKeySequence(iter.key()->text(2)));
 	}
 
 	QDialog::accept();
@@ -422,7 +486,7 @@ void qtractorShortcutForm::reject (void)
 	bool bReject = true;
 
 	// Check if there's any pending changes...
-	if (m_iDirtyCount > 0) {
+	if (m_iDirtyActionShortcuts > 0) {
 		QMessageBox::StandardButtons buttons
 			= QMessageBox::Discard | QMessageBox::Cancel;
 		if (m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->isEnabled())
@@ -441,10 +505,119 @@ void qtractorShortcutForm::reject (void)
 			bReject = false;
 		}
 	}
+	else
+	if (m_iDirtyActionControl > 0) {
+		QMessageBox::StandardButtons buttons
+			= QMessageBox::Discard | QMessageBox::Cancel;
+		if (m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->isEnabled())
+			buttons |= QMessageBox::Apply;
+		switch (QMessageBox::warning(this,
+			tr("Warning") + " - " QTRACTOR_TITLE,
+			tr("MIDI Controller shortcuts have been changed.\n\n"
+			"Do you want to apply the changes?"),
+			buttons)) {
+		case QMessageBox::Apply:
+			accept();
+			return;
+		case QMessageBox::Discard:
+			break;
+		default:    // Cancel.
+			bReject = false;
+		}
+	}
 
 	if (bReject)
 		QDialog::reject();
 }
 
 
+void qtractorShortcutForm::stabilizeForm (void)
+{
+	const bool bValid
+		= (m_iDirtyActionShortcuts > 0 || m_iDirtyActionControl > 0);
+	m_ui.DialogButtonBox->button(QDialogButtonBox::Ok)->setEnabled(bValid);
+}
+
+
+void qtractorShortcutForm::actionControlMenuRequested ( const QPoint& pos )
+{
+	if (m_pActionControl == NULL)
+		return;
+
+	QMenu menu(this);
+
+	menu.addAction(
+		QIcon(":/images/itemControllers.png"),
+		tr("&MIDI Controller..."), this,
+		SLOT(actionControlActivated()));
+
+	menu.exec(m_ui.ShortcutTable->viewport()->mapToGlobal(pos));
+}
+
+
+void qtractorShortcutForm::actionControlActivated (void)
+{
+	if (m_pActionControl == NULL)
+		return;
+
+	m_pActionControlItem = m_ui.ShortcutTable->currentItem();
+	if (m_pActionControlItem == NULL)
+		return;
+
+	QAction *pMidiObserverAction = m_actions.value(m_pActionControlItem, NULL);
+	if (pMidiObserverAction == NULL)
+		return;
+
+	qtractorMidiControlObserverForm::showInstance(pMidiObserverAction, this);
+
+	qtractorMidiControlObserverForm *pMidiObserverForm
+		= qtractorMidiControlObserverForm::getInstance();
+	if (pMidiObserverForm) {
+		QObject::connect(pMidiObserverForm,
+			SIGNAL(accepted()),
+			SLOT(actionControlAccepted()));
+	}
+}
+
+
+void qtractorShortcutForm::actionControlAccepted (void)
+{
+	if (m_pActionControl == NULL)
+		return;
+
+	if (m_pActionControlItem) {
+		QAction *pMidiObserverAction
+			= m_actions.value(m_pActionControlItem, NULL);
+		if (pMidiObserverAction) {
+			const QString& sText = actionControlText(pMidiObserverAction);
+			m_pActionControlItem->setText(3, sText);
+		}
+		m_pActionControlItem = NULL;
+		++m_iDirtyActionControl;
+	}
+
+	stabilizeForm();
+}
+
+
+QString qtractorShortcutForm::actionControlText ( QAction *pAction ) const
+{
+	QString sActionControlText;
+
+	if (m_pActionControl) {
+		qtractorActionControl::MidiObserver *pMidiObserver
+			= m_pActionControl->getMidiObserver(pAction);
+		if (pMidiObserver) {
+			QStringList clist;
+			clist.append(qtractorMidiControl::nameFromType(pMidiObserver->type()));
+			clist.append(QString::number(pMidiObserver->channel() + 1));
+			clist.append(QString::number(pMidiObserver->param()));
+			sActionControlText = clist.join(", ");
+		}
+	}
+
+	return sActionControlText;
+}
+
+
 // end of qtractorShortcutForm.cpp
