@@ -1,7 +1,7 @@
 // qtractorShortcutForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -24,12 +24,15 @@
 
 #include "ui_qtractorShortcutForm.h"
 
-
 #include <QHash>
+
 #include <QItemDelegate>
 #include <QLineEdit>
 
 
+// Forward decls.
+class qtractorActionControl;
+
 class QAction;
 class QToolButton;
 
@@ -140,6 +143,10 @@ protected:
 		QAbstractItemModel *pModel,
 		const QModelIndex& index) const;
 
+	QSize sizeHint(
+		const QStyleOptionViewItem& option,
+		const QModelIndex& index) const;
+
 protected slots:
 
 	void commitEditor();
@@ -161,33 +168,56 @@ public:
 
 	// Constructor.
 	qtractorShortcutForm(const QList<QAction *>& actions, QWidget *pParent = NULL);
-	
+
 	// Destructor.
 	~qtractorShortcutForm();
 
-	// Shortcut table widget accessor.
-	QTableWidget *tableWidget() const;
+	// Action shortcut/control table widget accessor.
+	QTreeWidget *tableWidget() const;
+
+	// MIDI Controller manager accessor.
+	void setActionControl(qtractorActionControl *pActionControl);
+	qtractorActionControl *actionControl() const;
+
+	// Action shortcut/control dirty-flag accessors.
+	bool isDirtyActionShortcuts() const;
+	bool isDirtyActionControl() const;
 
 	// Shortcut action finder & settler.
 	bool commitEditor(qtractorShortcutTableItemEditor *pItemEditor);
 
 protected slots:
 
-	void actionActivated(QTableWidgetItem *);
-	void actionChanged(QTableWidgetItem *);
+	void actionShortcutActivated(QTreeWidgetItem *, int);
+	void actionShortcutChanged(QTreeWidgetItem *, int);
+
+	void actionControlMenuRequested(const QPoint&);
+	void actionControlActivated();
+	void actionControlAccepted();
 
 	void accept();
 	void reject();
 
+protected:
+
+	QString actionControlText(QAction *pAction) const;
+
+	void stabilizeForm();
+
 private:
 
 	// The Qt-designer UI struct...
 	Ui::qtractorShortcutForm m_ui;
 
-	QHash<QAction *, int> m_actions;
-	QHash<QString, int> m_shortcuts;
+	qtractorActionControl *m_pActionControl;
 
-	int m_iDirtyCount;
+	QHash<QTreeWidgetItem *, QAction *> m_actions;
+	QHash<QString, QTreeWidgetItem *> m_shortcuts;
+
+	int m_iDirtyActionShortcuts;
+	int m_iDirtyActionControl;
+
+	QTreeWidgetItem *m_pActionControlItem;
 };
 
 
