@@ -1125,13 +1125,16 @@ unsigned long qtractorTrack::clipRecordEnd ( unsigned long iFrameTime ) const
 {
 	// HACK: Care of loop-recording + punch-in/out...
 	if (m_pSession && m_pSession->isPunching()) {
-		const unsigned long iLoopStart = m_pSession->loopStart();
-		const unsigned long iLoopEnd = m_pSession->loopEnd();
+		const unsigned long iPlayHead = m_pSession->playHead();
 		unsigned long iPunchIn = m_pSession->punchIn();
 		unsigned long iPunchOut = m_pSession->punchOut();
-		if (iLoopStart < iLoopEnd &&
-			iLoopEnd < iFrameTime &&
-			m_pSession->loopRecordingMode() > 0) {
+		if (iPlayHead < iPunchIn)
+			return iPunchIn; // Cancelled...
+		const unsigned long iLoopStart = m_pSession->loopStart();
+		const unsigned long iLoopEnd = m_pSession->loopEnd();
+		if (iLoopStart < iLoopEnd
+			&& m_pSession->loopRecordingMode() > 0
+			&& iLoopEnd > iPlayHead && iLoopEnd < iFrameTime) {
 			if (iPunchIn < iLoopStart)
 				iPunchIn = iLoopStart;
 			if (iPunchOut > iLoopEnd)
