@@ -1,7 +1,7 @@
 // qtractorTrack.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -175,14 +175,17 @@ public:
 	void removeClip(qtractorClip *pClip);
 
 	// Current clip on record (capture).
-	void setClipRecord(qtractorClip *pClipRecord,
-		unsigned long iClipRecordStart = 0);
+	void setClipRecord(qtractorClip *pClipRecord);
 	qtractorClip *clipRecord() const;
 
 	// Current clip on record absolute start frame (capture).
+	void setClipRecordStart(unsigned long iClipRecordStart);
 	unsigned long clipRecordStart() const;
 	unsigned long clipRecordEnd(unsigned long iFrameTime) const;
 
+	void setClipRecordEx(bool bClipRecordEx);
+	bool isClipRecordEx() const;
+
 	// Background color accessors.
 	void setBackground(const QColor& bg);
 	const QColor& background() const;
@@ -198,6 +201,10 @@ public:
 	void process(qtractorClip *pClip,
 		unsigned long iFrameStart, unsigned long iFrameEnd);
 
+	// Track freewheeling process cycle executive (needed for export).
+	void process_export(qtractorClip *pClip,
+		unsigned long iFrameStart, unsigned long iFrameEnd);
+
 	// Track special process record executive (audio recording only).
 	void process_record(
 		unsigned long iFrameStart, unsigned long iFrameEnd);
@@ -344,6 +351,8 @@ private:
 	qtractorClip *m_pClipRecord;        // Current clip on record (capture).
 	unsigned long m_iClipRecordStart;   // Current clip on record start frame.
 
+	bool m_bClipRecordEx;               // Current clip on record/overdub flag.
+
 	qtractorPluginList *m_pPluginList;	// Plugin chain (audio).
 
 	// Audio buffer ring-cache (playlist).
