@@ -1,7 +1,7 @@
 // qtractorTrackList.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -42,6 +42,8 @@
 
 #include "qtractorCurve.h"
 
+#include "qtractorOptions.h"
+
 #include <QHeaderView>
 
 #include <QApplication>
@@ -151,6 +153,8 @@ QVariant qtractorTrackListHeaderModel::headerData (
 				return int(Qt::AlignHCenter | Qt::AlignVCenter);
 			else
 				return int(Qt::AlignLeft | Qt::AlignVCenter);
+		case Qt::SizeHintRole:
+			return QSize(100, 24);
 		}
 	}	
 
@@ -254,9 +258,24 @@ qtractorTrackList::qtractorTrackList ( qtractorTracks *pTracks, QWidget *pParent
 	const QFont& font = qtractorScrollView::font();
 	qtractorScrollView::setFont(QFont(font.family(), font.pointSize() - 1));
 
+	// Load header section (column) sizes...
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions) {
+		QSettings& settings = pOptions->settings();
+		settings.beginGroup("Tracks");
+		const QByteArray& aHeaderView
+			= pOptions->settings().value("/TrackList/HeaderView").toByteArray();
+		if (!aHeaderView.isEmpty())
+			m_pHeader->restoreState(aHeaderView);
+		settings.endGroup();
+	}
+
 	QObject::connect(m_pHeader,
 		SIGNAL(sectionResized(int,int,int)),
-		SLOT(updateHeader()));
+		SLOT(updateHeaderSize(int,int,int)));
+	QObject::connect(m_pHeader,
+		SIGNAL(sectionHandleDoubleClicked(int)),
+		SLOT(resetHeaderSize(int)));
 
 //	QObject::connect(this, SIGNAL(contentsMoving(int,int)),
 //		this, SLOT(updatePixmap(int,int)));
@@ -266,6 +285,15 @@ qtractorTrackList::qtractorTrackList ( qtractorTracks *pTracks, QWidget *pParent
 // Destructor.
 qtractorTrackList::~qtractorTrackList (void)
 {
+	// Save header section (column) sizes...
+	qtractorOptions *pOptions = qtractorOptions::getInstance();
+	if (pOptions) {
+		QSettings& settings = pOptions->settings();
+		settings.beginGroup("Tracks");
+		settings.setValue("/TrackList/HeaderView", m_pHeader->saveState());
+		settings.endGroup();
+	}
+
 	delete m_pPixmap[IconAudio];
 	delete m_pPixmap[IconMidi];
 }
@@ -287,7 +315,7 @@ QHeaderView *qtractorTrackList::header (void) const
 
 // Track-list model item constructor
 qtractorTrackList::Item::Item ( qtractorTrackList *pTrackList,
-	qtractorTrack *pTrack ) : track(pTrack), widget(NULL)
+	qtractorTrack *pTrack ) : track(pTrack), flags(0), widget(NULL)
 {
 	update(pTrackList);
 }
@@ -383,10 +411,12 @@ void qtractorTrackList::Item::update ( qtractorTrackList *pTrackList )
 			QString sInstrument = s;
 			QString sProg = s;
 			QString sBank;
-			if (track->midiProg() >= 0)
-				sProg = QString::number(track->midiProg() + 1) + s;
-			if (track->midiBank() >= 0)
-				sBank = QString::number(track->midiBank());
+			const int iProg = track->midiProg();
+			if (iProg >= 0)
+				sProg = QString::number(iProg + 1) + s;
+			const int iBank = track->midiBank();
+			if (iBank >= 0)
+				sBank = QString::number(iBank);
 			if (pMidiBus) {
 				const qtractorMidiBus::Patch& patch
 					= pMidiBus->patch(iChannel);
@@ -411,9 +441,9 @@ void qtractorTrackList::Item::update ( qtractorTrackList *pTrackList )
 							qtractorInstrument& instr
 								= (*pInstruments)[sInstrument];
 							const qtractorInstrumentData& bank
-								= instr.patch(track->midiBank());
-							if (bank.contains(track->midiProg())) {
-								sProg = bank[track->midiProg()];
+								= instr.patch(iBank);
+							if (bank.contains(iProg)) {
+								sProg = bank[iProg];
 								sBank = bank.name();
 							}
 						}
@@ -451,18 +481,16 @@ int qtractorTrackList::trackRow ( qtractorTrack *pTrack ) const
 }
 
 
-// Find track row of given viewport point...
+// Find track row of given contents point...
 int qtractorTrackList::trackRowAt ( const QPoint& pos )
 {
-	const int cy = qtractorScrollView::contentsY();
-	const int  y = cy + pos.y() - m_pHeader->sizeHint().height();
-	const int  h = qtractorScrollView::viewport()->height();
+	const int y = pos.y() - m_pHeader->sizeHint().height();
 
 	int y1, y2;
 	y1 = y2 = 0;
 	int iTrack = 0;
 	QListIterator<Item *> iter(m_items);
-	while (iter.hasNext() && y2 < cy + h) {
+	while (iter.hasNext() && y2 < qtractorScrollView::contentsHeight()) {
 		y1  = y2;
 		y2 += (iter.next()->track)->zoomHeight();
 		if (y >= y1 && y < y2)
@@ -474,15 +502,13 @@ int qtractorTrackList::trackRowAt ( const QPoint& pos )
 }
 
 
-// Find track column of given viewport point...
+// Find track column of given contents point...
 int qtractorTrackList::trackColumnAt ( const QPoint& pos )
 {
-	const int cy = qtractorScrollView::contentsY();
-	const int  y = cy + pos.y() - m_pHeader->sizeHint().height();
+	const int y = pos.y() - m_pHeader->sizeHint().height();
 
 	if (y > 0 && y < qtractorScrollView::contentsHeight()) {
-		const int cx = qtractorScrollView::contentsX();
-		const int  x = cx + pos.x();
+		const int x = pos.x();
 		int x1, x2;
 		x1 = x2 = 0;
 		const int iColCount = m_pHeader->count();
@@ -538,6 +564,8 @@ QRect qtractorTrackList::trackRect ( int iTrack ) const
 // Insert a track item; return actual track row added.
 int qtractorTrackList::insertTrack ( int iTrack, qtractorTrack *pTrack )
 {
+	clearSelect();
+
 	if (iTrack < 0)
 		iTrack = m_items.count();
 
@@ -553,6 +581,11 @@ int qtractorTrackList::removeTrack ( int iTrack )
 	if (iTrack < 0 || iTrack >= m_items.count())
 		return -1;
 
+	clearSelect();
+
+	if (m_select.contains(iTrack))
+		m_select.remove(iTrack);
+
 	delete m_items.at(iTrack);
 	m_items.removeAt(iTrack);
 
@@ -580,6 +613,9 @@ void qtractorTrackList::setCurrentTrackRow ( int iTrack )
 
 	m_iCurrentTrack = iCurrentTrack;
 
+	if (m_iCurrentTrack < 0)
+		clearSelect();
+
 	// Make sure the new current track is visible...
 	if (!ensureVisibleRect(trackRect(m_iCurrentTrack)))
 		updateContents();
@@ -635,6 +671,8 @@ void qtractorTrackList::updateTrack ( qtractorTrack *pTrack )
 // Main table cleaner.
 void qtractorTrackList::clear (void)
 {
+	clearSelect();
+
 	m_iCurrentTrack = -1;
 
 	m_dragState  = DragNone;
@@ -718,6 +756,16 @@ void qtractorTrackList::resizeEvent ( QResizeEvent *pResizeEvent )
 }
 
 
+// Check/update header resize.
+void qtractorTrackList::updateHeaderSize ( int iCol, int, int iColSize )
+{
+	if (iCol == Name && iColSize < 110)
+		m_pHeader->resizeSection(iCol, 110);
+
+	updateHeader();
+}
+
+
 // Update header extents.
 void qtractorTrackList::updateHeader (void)
 {
@@ -736,9 +784,123 @@ void qtractorTrackList::updateHeader (void)
 }
 
 
+// Reset header extents.
+void qtractorTrackList::resetHeaderSize ( int iCol )
+{
+	static const int s_aiDefaultHeaderSizes[] = { 26, 120, 100, 24, 100, 100 };
+
+	m_pHeader->resizeSection(iCol, s_aiDefaultHeaderSizes[iCol]);
+}
+
+
+// Selection method.
+void qtractorTrackList::selectTrack ( int iTrack, bool bSelect, bool bToggle )
+{
+	Item *pItem = m_items.at(iTrack);
+
+	if (m_select.contains(iTrack)) {
+		const unsigned int flags = pItem->flags;
+		if ( (!bSelect && (flags & 2) == 0) ||
+			(( bSelect && (flags & 3) == 3) && bToggle))
+			pItem->flags &= ~1;
+		else
+		if ( ( bSelect && (flags & 2) == 0) ||
+			((!bSelect && (flags & 3) == 2) && bToggle))
+			pItem->flags |=  1;
+	}
+	else
+	if (bSelect) {
+		pItem->flags = 1;
+		m_select.insert(iTrack, pItem);
+	}
+}
+
+
+// Selection commit method.
+void qtractorTrackList::updateSelect ( bool bCommit )
+{
+	// Remove unselected...
+	QHash<int, Item *>::Iterator iter = m_select.begin();
+	const QHash<int, Item *>::Iterator& iter_end = m_select.end();
+	while (iter != iter_end) {
+		Item *pItem = iter.value();
+		if (bCommit) {
+			if (pItem->flags & 1)
+				pItem->flags |=  2;
+			else
+				pItem->flags &= ~2;
+		}
+		if ((pItem->flags & 3) == 0)
+			iter = m_select.erase(iter);
+		else
+			++iter;
+	}
+
+	updateContents();
+}
+
+
+// Selection clear method.
+void qtractorTrackList::clearSelect (void)
+{
+	int iUpdate = 0;
+
+	// Clear all selected...
+	QHash<int, Item *>::ConstIterator iter = m_select.constBegin();
+	const QHash<int, Item *>::ConstIterator& iter_end = m_select.constEnd();
+	for ( ; iter != iter_end; ++iter) {
+		iter.value()->flags = 0;
+		++iUpdate;
+	}
+
+	m_select.clear();
+
+	if (iUpdate > 0)
+		updateContents();
+}
+
+
+// Retrieve all current seleceted tracks but one.
+QList<qtractorTrack *> qtractorTrackList::selectedTracks(
+	qtractorTrack *pTrackEx, bool bAllTracks ) const
+{
+	QList<qtractorTrack *> tracks;
+
+	// Grab current selected tracks; also check
+	// whether given track is currently selected...
+	bool bSelected = false;
+	QHash<int, Item *>::ConstIterator iter = m_select.constBegin();
+	const QHash<int, Item *>::ConstIterator& iter_end = m_select.constEnd();
+	for ( ; iter != iter_end; ++iter) {
+		qtractorTrack *pTrack = iter.value()->track;
+		if (pTrackEx == pTrack)
+			bSelected = true;
+		else
+			tracks.append(pTrack);
+	}
+
+	// Currentt selection is either empty or
+	// given track is not currently selected...
+	if (!bSelected) {
+		tracks.clear();
+		// Optionally apply to all tracks
+		if (bAllTracks) {
+			QListIterator<Item *> iter(m_items);
+			while (iter.hasNext()) {
+				qtractorTrack *pTrack = iter.next()->track;
+				if (pTrackEx != pTrack)
+					tracks.append(pTrack);
+			}
+		}
+	}
+
+	return tracks;
+}
+
+
 // Draw table cell.
-void qtractorTrackList::drawCell ( QPainter *pPainter, int iRow, int iCol,
-	const QRect& rect ) const
+void qtractorTrackList::drawCell (
+	QPainter *pPainter, int iRow, int iCol, const QRect& rect ) const
 {
 	const QPalette& pal = qtractorScrollView::palette();
 	const Item *pItem = m_items.at(iRow);
@@ -746,6 +908,11 @@ void qtractorTrackList::drawCell ( QPainter *pPainter, int iRow, int iCol,
 	if (iCol == Number) {
 		bg = (pItem->track)->foreground().lighter();
 		fg = (pItem->track)->background().lighter();
+	} else if (pItem->flags & 1) {
+		bg = pal.highlight().color();
+		fg = pal.highlightedText().color();
+		if (m_iCurrentTrack == iRow)
+			bg = bg.darker(140);
 	} else if (m_iCurrentTrack == iRow) {
 		bg = pal.midlight().color().darker(160);
 		fg = pal.highlightedText().color();
@@ -927,21 +1094,31 @@ void qtractorTrackList::mouseDoubleClickEvent ( QMouseEvent * /*pMouseEvent*/ )
 // Handle item selection/dragging -- mouse button press.
 void qtractorTrackList::mousePressEvent ( QMouseEvent *pMouseEvent )
 {
-	const QPoint& pos = pMouseEvent->pos();
+	const QPoint& pos
+		= qtractorScrollView::viewportToContents(pMouseEvent->pos());
 
 	// Select current track...
 	const int iTrack = trackRowAt(pos);
-	setCurrentTrackRow(iTrack);
 
 	// Look for the mouse hovering around some item boundary...
 	if (iTrack >= 0) {
 		// Special attitude, only of interest on
-		// the first-left column (track-number)...
+		// the first left-most column (track-number)...
 		if (trackColumnAt(pos) == Number) {
 			m_pTracks->selectCurrentTrack((pMouseEvent->modifiers()
 				& (Qt::ShiftModifier | Qt::ControlModifier)) == 0);
+			qtractorScrollView::setFocus(); // get focus back anyway.
 		}
+		// Now set ready for drag something...
 		if (pMouseEvent->button() == Qt::LeftButton) {
+			// Make current row always selected...
+			const Qt::KeyboardModifiers& modifiers = pMouseEvent->modifiers();
+			if ((modifiers & (Qt::ShiftModifier | Qt::ControlModifier)) == 0) {
+				clearSelect();
+			} else {
+				selectTrack(iTrack, true, (modifiers & Qt::ControlModifier));
+				updateSelect(true);
+			}
 			// Try for drag-resize...
 			m_posDrag = pos;
 			if (m_iDragTrack >= 0) {
@@ -955,6 +1132,8 @@ void qtractorTrackList::mousePressEvent ( QMouseEvent *pMouseEvent )
 		}
 	}
 
+	setCurrentTrackRow(iTrack);
+
 	// Probably this would be done ahead,
 	// just 'coz we're using ruberbands, which are
 	// in fact based on real widgets (WM entities)...
@@ -965,7 +1144,8 @@ void qtractorTrackList::mousePressEvent ( QMouseEvent *pMouseEvent )
 // Handle item selection/dragging -- mouse pointer move.
 void qtractorTrackList::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 {
-	const QPoint& pos = pMouseEvent->pos();
+	const QPoint& pos
+		= qtractorScrollView::viewportToContents(pMouseEvent->pos());
 
 	// We're already on some item dragging/resizing?...
 	switch (m_dragState) {
@@ -995,15 +1175,50 @@ void qtractorTrackList::mouseMoveEvent ( QMouseEvent *pMouseEvent )
 			moveRubberBand(m_posDrag);
 		}
 		break;
+	case DragSelect:
+		// Currently selecting an group of items...
+		if (m_iDragTrack >= 0 && m_iCurrentTrack >= 0) {
+			const int iTrack = trackRowAt(pos);
+			ensureVisibleRect(trackRect(iTrack));
+			if (iTrack >= 0 && m_iDragTrack != iTrack) {
+				const Qt::KeyboardModifiers& modifiers = pMouseEvent->modifiers();
+				const bool bToggle = (modifiers & Qt::ControlModifier);
+				if ((modifiers & (Qt::ShiftModifier | Qt::ControlModifier)) == 0)
+					selectTrack(m_iCurrentTrack, true, bToggle);
+				if (iTrack < m_iCurrentTrack) {
+					for (int i = iTrack; i < m_iCurrentTrack; ++i)
+						selectTrack(i, true, bToggle);
+				} else if (iTrack > m_iCurrentTrack) {
+					for (int i = iTrack; i > m_iCurrentTrack; --i)
+						selectTrack(i, true, bToggle);
+				}
+				if ((m_iDragTrack > iTrack && m_iDragTrack > m_iCurrentTrack) ||
+					(m_iDragTrack < iTrack && m_iDragTrack < m_iCurrentTrack)) {
+					const bool bSelect = !m_select.contains(m_iDragTrack);
+					selectTrack(m_iDragTrack, bSelect, bToggle);
+				}
+			//	selectTrack(iTrack, true, bToggle);
+				updateSelect(false);
+				m_iDragTrack = iTrack;
+			}
+			moveRubberBand(QRect(m_posDrag, pos));
+		}
+		break;
 	case DragStart:
 		// About to start dragging an item...
 		if (m_iDragTrack >= 0
 			&& (m_posDrag - pos).manhattanLength()
 				> QApplication::startDragDistance()) {
-			qtractorScrollView::setCursor(QCursor(Qt::SizeVerCursor));
-			m_dragState = DragMove;
-			m_posDrag   = trackRect(m_iDragTrack).topLeft();
-			moveRubberBand(m_posDrag);
+			if (trackColumnAt(pos) == Number) {
+				qtractorScrollView::setCursor(QCursor(Qt::SizeVerCursor));
+				m_dragState = DragMove;
+				m_posDrag   = trackRect(m_iDragTrack).topLeft();
+				moveRubberBand(m_posDrag);
+			} else {
+				qtractorScrollView::setCursor(QCursor(Qt::CrossCursor));
+				m_dragState = DragSelect;
+				moveRubberBand(QRect(m_posDrag, pos));
+			}
 		}
 		break;
 	case DragNone: {
@@ -1056,7 +1271,8 @@ void qtractorTrackList::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 	if (pSession == NULL)
 		return;
 
-	const QPoint& pos = pMouseEvent->pos();
+	const QPoint& pos
+		= qtractorScrollView::viewportToContents(pMouseEvent->pos());
 
 	// If we were resizing, now's time to let
 	// things know that have changed somehow...
@@ -1071,6 +1287,7 @@ void qtractorTrackList::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 					pTrackDrop = track(iTrack);
 				if (pTrack != pTrackDrop
 					&& (pTrackDrop == NULL || pTrack != pTrackDrop->prev())) {
+					clearSelect();
 					pSession->execute(
 						new qtractorMoveTrackCommand(pTrack, pTrackDrop));
 				}
@@ -1090,6 +1307,10 @@ void qtractorTrackList::mouseReleaseEvent ( QMouseEvent *pMouseEvent )
 					new qtractorResizeTrackCommand(pTrack, iZoomHeight));
 			}
 		}
+		break;
+	case DragSelect:
+		if (m_iDragTrack >= 0)
+			updateSelect(true);
 		// Fall thru...
 	case DragStart:
 	case DragNone:
@@ -1139,6 +1360,32 @@ void qtractorTrackList::moveRubberBand ( const QPoint& posDrag )
 }
 
 
+// Draw a lasso rectangle.
+void qtractorTrackList::moveRubberBand ( const QRect& rectDrag )
+{
+	QRect rect(rectDrag.normalized());
+
+	rect.moveTopLeft(qtractorScrollView::contentsToViewport(rect.topLeft()));
+
+	// Create the rubber-band if there's none...
+	if (m_pRubberBand == NULL) {
+		m_pRubberBand = new qtractorRubberBand(
+			QRubberBand::Rectangle, qtractorScrollView::viewport());
+	//	QPalette pal(m_pRubberBand->palette());
+	//	pal.setColor(m_pRubberBand->foregroundRole(), Qt::blue);
+	//	m_pRubberBand->setPalette(pal);
+	//	m_pRubberBand->setBackgroundRole(QPalette::NoRole);
+	}
+
+	// Just move it
+	m_pRubberBand->setGeometry(rect);
+
+	// Ah, and make it visible, of course...
+	if (!m_pRubberBand->isVisible())
+		m_pRubberBand->show();
+}
+
+
 // Make sure the given (track) rectangle is visible.
 bool qtractorTrackList::ensureVisibleRect ( const QRect& rect )
 {
@@ -1188,29 +1435,39 @@ void qtractorTrackList::keyPressEvent ( QKeyEvent *pKeyEvent )
 #ifdef CONFIG_DEBUG_0
 	qDebug("qtractorTrackList::keyPressEvent(%d)", pKeyEvent->key());
 #endif
+	const Qt::KeyboardModifiers& modifiers = pKeyEvent->modifiers();
+
 	switch (pKeyEvent->key()) {
 	case Qt::Key_Escape:
 		resetDragState();
+		clearSelect();
 		break;
 	case Qt::Key_Home:
-		if (pKeyEvent->modifiers() & Qt::ControlModifier) {
-			setCurrentTrackRow(0);
-		} else {
-			qtractorScrollView::setContentsPos(
-				0, qtractorScrollView::contentsY());
+		if (m_iCurrentTrack  > 0) {
+			const int iTrack = 0;
+			if (modifiers & (Qt::ShiftModifier | Qt::ControlModifier)) {
+				const bool bToggle = (modifiers & Qt::ControlModifier);
+				for (int i = iTrack; m_iCurrentTrack >= i; ++i)
+					selectTrack(i, true, bToggle);
+				updateSelect(true);
+			}
+			setCurrentTrackRow(iTrack);
 		}
 		break;
 	case Qt::Key_End:
-		if (pKeyEvent->modifiers() & Qt::ControlModifier) {
-			setCurrentTrackRow(m_items.count() - 1);
-		} else {
-			qtractorScrollView::setContentsPos(
-				qtractorScrollView::contentsWidth(),
-				qtractorScrollView::contentsY());
+		if (m_iCurrentTrack  < m_items.count() - 1) {
+			const int iTrack = m_items.count() - 1;
+			if (modifiers & (Qt::ShiftModifier | Qt::ControlModifier)) {
+				const bool bToggle = (modifiers & Qt::ControlModifier);
+				for (int i = iTrack; i >= m_iCurrentTrack; --i)
+					selectTrack(i, true, bToggle);
+				updateSelect(true);
+			}
+			setCurrentTrackRow(iTrack);
 		}
 		break;
 	case Qt::Key_Left:
-		if (pKeyEvent->modifiers() & Qt::ControlModifier) {
+		if (modifiers & Qt::ControlModifier) {
 			qtractorScrollView::setContentsPos(
 				qtractorScrollView::contentsX() - qtractorScrollView::width(),
 				qtractorScrollView::contentsY());
@@ -1221,7 +1478,7 @@ void qtractorTrackList::keyPressEvent ( QKeyEvent *pKeyEvent )
 		}
 		break;
 	case Qt::Key_Right:
-		if (pKeyEvent->modifiers() & Qt::ControlModifier) {
+		if (modifiers & Qt::ControlModifier) {
 			qtractorScrollView::setContentsPos(
 				qtractorScrollView::contentsX() + qtractorScrollView::width(),
 				qtractorScrollView::contentsY());
@@ -1232,15 +1489,31 @@ void qtractorTrackList::keyPressEvent ( QKeyEvent *pKeyEvent )
 		}
 		break;
 	case Qt::Key_Up:
-		if (m_iCurrentTrack > 0)
-			setCurrentTrackRow(m_iCurrentTrack - 1);
+		if (m_iCurrentTrack > 0) {
+			const int iTrack = m_iCurrentTrack - 1;
+			if (modifiers & (Qt::ShiftModifier | Qt::ControlModifier)) {
+				const bool bToggle = (modifiers & Qt::ControlModifier);
+				selectTrack(m_iCurrentTrack, true, bToggle);
+				selectTrack(iTrack, true, bToggle);
+				updateSelect(true);
+			}
+			setCurrentTrackRow(iTrack);
+		}
 		break;
 	case Qt::Key_Down:
-		if (m_iCurrentTrack < m_items.count() - 1)
-			setCurrentTrackRow(m_iCurrentTrack + 1);
+		if (m_iCurrentTrack < m_items.count() - 1) {
+			const int iTrack = m_iCurrentTrack + 1;
+			if (modifiers & (Qt::ShiftModifier | Qt::ControlModifier)) {
+				const bool bToggle = (modifiers & Qt::ControlModifier);
+				selectTrack(m_iCurrentTrack, true, bToggle);
+				selectTrack(iTrack, true, bToggle);
+				updateSelect(true);
+			}
+			setCurrentTrackRow(iTrack);
+		}
 		break;
 	case Qt::Key_PageUp:
-		if (pKeyEvent->modifiers() & Qt::ControlModifier) {
+		if (modifiers & Qt::ControlModifier) {
 			qtractorScrollView::setContentsPos(
 				qtractorScrollView::contentsX(), 0);
 		} else {
@@ -1251,7 +1524,7 @@ void qtractorTrackList::keyPressEvent ( QKeyEvent *pKeyEvent )
 		}
 		break;
 	case Qt::Key_PageDown:
-		if (pKeyEvent->modifiers() & Qt::ControlModifier) {
+		if (modifiers & Qt::ControlModifier) {
 			qtractorScrollView::setContentsPos(
 				qtractorScrollView::contentsX(),
 				qtractorScrollView::contentsHeight());
