@@ -1,7 +1,7 @@
 // qtractorTracks.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -164,6 +164,9 @@ public:
 	// Track-list update (current track only).
 	void updateTrackList(qtractorTrack *pTrack = NULL);
 
+	// Update/sync recording tracks.
+	void updateContentsRecord();
+
 protected:
 
 	// Zoom factor constants.
