@@ -28,12 +28,12 @@
 #include "qtractorPluginForm.h"
 
 #include "qtractorMidiBuffer.h"
-
 #include "qtractorSession.h"
 
 #ifdef QTRACTOR_VST_EDITOR_TOOL
 #include "qtractorOptions.h"
 #endif
+#include "qtractorMainForm.h"
 
 #include <QApplication>
 #include <QFileDialog>
@@ -47,13 +47,19 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 #endif
 
 
-#if defined(Q_WS_X11)
+#ifdef CONFIG_VST_X11
+
 #include <QX11Info>
+
+#if QT_VERSION < 0x050000
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 typedef void (*XEventProc)(XEvent *);
 #endif
 
+#endif	// CONFIG_VST_X11
+
+
 #if !defined(VST_2_3_EXTENSIONS)
 #ifdef CONFIG_VESTIGE
 typedef int32_t  VstInt32;
@@ -101,7 +107,8 @@ const int effFlagsProgramChunks = 32;
 //---------------------------------------------------------------------
 // qtractorVstPlugin::EditorWidget - Helpers for own editor widget.
 
-#if defined(Q_WS_X11)
+#ifdef CONFIG_VST_X11
+#if QT_VERSION < 0x050000
 
 static bool g_bXError = false;
 
@@ -122,7 +129,7 @@ static XEventProc getXEventProc ( Display *pDisplay, Window w )
 	g_bXError = false;
 	XErrorHandler oldErrorHandler = XSetErrorHandler(tempXErrorHandler);
 	XGetWindowProperty(pDisplay, w, aName, 0, 1, false,
-		AnyPropertyType, &aType,  &iSize, &iCount, &iBytes, &pData);
+		AnyPropertyType, &aType, &iSize, &iCount, &iBytes, &pData);
 	if (g_bXError == false && iCount == 1)
 		eventProc = (XEventProc) (pData);
 	XSetErrorHandler(oldErrorHandler);
@@ -140,7 +147,8 @@ static Window getXChildWindow ( Display *pDisplay, Window w )
 	return (iChildren > 0 ? pwChildren[0] : 0);
 }
 
-#endif // Q_WS_X11
+#endif
+#endif // CONFIG_VST_X11
 
 
 //----------------------------------------------------------------------------
@@ -157,12 +165,14 @@ public:
 	// Constructor.
 	EditorWidget(QWidget *pParent, Qt::WindowFlags wflags = 0)
 		: QWidget(pParent, wflags),
-	#if defined(Q_WS_X11)
+	#ifdef CONFIG_VST_X11
 		m_pDisplay(QX11Info::display()),
+	#if QT_VERSION < 0x050000
 		m_wVstEditor(0),
 		m_pVstEventProc(NULL),
 		m_bButtonPress(false),
 	#endif
+	#endif	// CONFIG_VST_X11
 		m_pVstPlugin(NULL) {}
 
 	// Destructor.
@@ -176,7 +186,7 @@ public:
 		// Start the proper (child) editor...
 		long  value = 0;
 		void *ptr = (void *) winId();
-	#if defined(Q_WS_X11)
+	#ifdef CONFIG_VST_X11
 		value = (long) m_pDisplay;
 	#endif
 
@@ -197,11 +207,13 @@ public:
 
 		m_pVstPlugin->vst_dispatch(0, effEditOpen, 0, value, ptr, 0.0f);
 		
-	#if defined(Q_WS_X11)
+	#ifdef CONFIG_VST_X11
+	#if QT_VERSION < 0x050000
 		m_wVstEditor = getXChildWindow(m_pDisplay, (Window) winId());
 		if (m_wVstEditor)
 			m_pVstEventProc = getXEventProc(m_pDisplay, m_wVstEditor);
 	#endif
+	#endif	// CONFIG_VST_X11
 
 		g_vstEditors.append(this);
 
@@ -226,7 +238,8 @@ public:
 			g_vstEditors.removeAt(iIndex);
 	}
 
-#if defined(Q_WS_X11)
+#ifdef CONFIG_VST_X11
+#if QT_VERSION < 0x050000
 	// Local X11 event filter.
 	bool x11EventFilter(XEvent *pEvent)
 	{
@@ -254,6 +267,7 @@ public:
 		}
 	}
 #endif
+#endif	// CONFIG_VST_X11
 
 	qtractorVstPlugin *plugin() const
 		{ return m_pVstPlugin; }
@@ -265,14 +279,14 @@ protected:
 	{
 		QWidget::showEvent(pShowEvent);
 
-		if (m_pVstPlugin && m_pVstPlugin->isFormVisible())
-			(m_pVstPlugin->form())->toggleEditor(true);
+		if (m_pVstPlugin)
+			m_pVstPlugin->toggleFormEditor(true);
 	}
 
 	void closeEvent(QCloseEvent *pCloseEvent)
 	{
-		if (m_pVstPlugin && m_pVstPlugin->isFormVisible())
-			(m_pVstPlugin->form())->toggleEditor(false);
+		if (m_pVstPlugin)
+			m_pVstPlugin->toggleFormEditor(false);
 
 		QWidget::closeEvent(pCloseEvent);
 
@@ -280,7 +294,8 @@ protected:
 			m_pVstPlugin->closeEditor();
 	}
 
-#if defined(Q_WS_X11)
+#ifdef CONFIG_VST_X11
+#if QT_VERSION < 0x050000
 	void moveEvent(QMoveEvent *pMoveEvent)
 	{
 		QWidget::moveEvent(pMoveEvent);
@@ -290,16 +305,19 @@ protected:
 		}
 	}
 #endif
+#endif	// CONFIG_VST_X11
 
 private:
 
 	// Instance variables...
-#if defined(Q_WS_X11)
+#ifdef CONFIG_VST_X11
 	Display   *m_pDisplay;
+#if QT_VERSION < 0x050000
 	Window     m_wVstEditor;
 	XEventProc m_pVstEventProc;
 	bool       m_bButtonPress;
 #endif
+#endif	// CONFIG_VST_X11
 
 	qtractorVstPlugin *m_pVstPlugin;
 };
@@ -1031,14 +1049,12 @@ int qtractorVstPlugin::vst_dispatch( unsigned short iInstance,
 
 
 // Open editor.
-void qtractorVstPlugin::openEditor ( QWidget */*pParent*/ )
+void qtractorVstPlugin::openEditor ( QWidget *pParent )
 {
 	// Is it already there?
 	if (m_pEditorWidget) {
 		if (!m_pEditorWidget->isVisible()) {
-			const QPoint& posEditor = editorPos();
-			if (!posEditor.isNull())
-				m_pEditorWidget->move(posEditor);
+			moveWidgetPos(m_pEditorWidget, editorPos());
 			m_pEditorWidget->show();
 		}
 		m_pEditorWidget->raise();
@@ -1054,6 +1070,9 @@ void qtractorVstPlugin::openEditor ( QWidget */*pParent*/ )
 	m_bEditorClosed = false;
 
 	// Create the new parent frame...
+	if (pParent == NULL)
+		pParent = qtractorMainForm::getInstance();
+
 	Qt::WindowFlags wflags = Qt::Window
 		| Qt::CustomizeWindowHint
 		| Qt::WindowTitleHint
@@ -1065,7 +1084,7 @@ void qtractorVstPlugin::openEditor ( QWidget */*pParent*/ )
 	if (pOptions && pOptions->bKeepToolsOnTop)
 		wflags |= Qt::Tool;
 #endif
-	m_pEditorWidget = new EditorWidget(NULL, wflags);
+	m_pEditorWidget = new EditorWidget(pParent, wflags);
 	m_pEditorWidget->open(this);
 }
 
@@ -1113,12 +1132,10 @@ void qtractorVstPlugin::idleEditor (void)
 void qtractorVstPlugin::setEditorVisible ( bool bVisible )
 {
 	if (m_pEditorWidget) {
-		if (bVisible) {
-			const QPoint& posEditor = editorPos();
-			if (!posEditor.isNull())
-				m_pEditorWidget->move(posEditor);
-		}
-		else setEditorPos(m_pEditorWidget->pos());
+		if (bVisible)
+			moveWidgetPos(m_pEditorWidget, editorPos());
+		else
+			setEditorPos(m_pEditorWidget->pos());
 		m_pEditorWidget->setVisible(bVisible);
 	}
 }
@@ -1162,7 +1179,7 @@ QWidget *qtractorVstPlugin::editorWidget (void) const
 void qtractorVstPlugin::resizeEditor ( int w, int h )
 {
 	if (m_pEditorWidget && w > 0 && h > 0)
-		m_pEditorWidget->resize(w, h);
+		m_pEditorWidget->setFixedSize(w, h);
 }
 
 
@@ -1173,7 +1190,8 @@ qtractorVstPlugin *qtractorVstPlugin::findPlugin ( AEffect *pVstEffect )
 }
 
 
-#if defined(Q_WS_X11)
+#ifdef CONFIG_VST_X11
+#if QT_VERSION < 0x050000
 
 // Global X11 event filter.
 bool qtractorVstPlugin::x11EventFilter ( void *pvEvent )
@@ -1190,6 +1208,7 @@ bool qtractorVstPlugin::x11EventFilter ( void *pvEvent )
 }
 
 #endif
+#endif	// CONFIG_VST_X11
 
 
 // Parameter update method.
@@ -1207,8 +1226,7 @@ void qtractorVstPlugin::updateParamValues ( bool bUpdate )
 			float fValue = pVstEffect->getParameter(pVstEffect, pParam->index());
 			if (pParam->value() != fValue) {
 				pParam->setValue(fValue, bUpdate);
-				if (isFormVisible())
-					form()->changeParamValue(pParam->index());
+				updateFormParamValue(pParam->index());
 			}
 		}
 	}
